/*=========================================================================

Copyright (c) 2017, Los Alamos National Security, LLC

All rights reserved.

Copyright 2017. Los Alamos National Security, LLC.
This software was produced under U.S. Government contract DE-AC52-06NA25396
for Los Alamos National Laboratory (LANL), which is operated by
Los Alamos National Security, LLC for the U.S. Department of Energy.
The U.S. Government has rights to use, reproduce, and distribute this software.
NEITHER THE GOVERNMENT NOR LOS ALAMOS NATIONAL SECURITY, LLC MAKES ANY WARRANTY,
EXPRESS OR IMPLIED, OR ASSUMES ANY LIABILITY FOR THE USE OF THIS SOFTWARE.
If software is modified to produce derivative works, such modified software
should be clearly marked, so as not to confuse it with the version available
from LANL.

Additionally, redistribution and use in source and binary forms, with or
without modification, are permitted provided that the following conditions
are met:
-   Redistributions of source code must retain the above copyright notice,
    this list of conditions and the following disclaimer.
-   Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation
    and/or other materials provided with the distribution.
-   Neither the name of Los Alamos National Security, LLC, Los Alamos National
    Laboratory, LANL, the U.S. Government, nor the names of its contributors
    may be used to endorse or promote products derived from this software
    without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY LOS ALAMOS NATIONAL SECURITY, LLC AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL LOS ALAMOS NATIONAL SECURITY, LLC OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

#ifndef _GIO_PV_LOG_H_
#define _GIO_PV_LOG_H_

#include <fstream>
#include <sstream>
#include <string>

namespace GIOPvPlugin
{

class Log
{
  std::string outputFilename;
  std::string logMsg;

public:
  Log();
  Log(std::string _outputFilename)
    : outputFilename(_outputFilename)
  {
    clearLog();
  }
  ~Log() { clearLog(); }

  void setOutputFilename(std::string _outputFilename) { outputFilename = _outputFilename; }
  void clearLog() { logMsg = ""; }
  std::string getLog() { return logMsg; }

  void addLog(std::stringstream& _msgLog);
  void addLog(std::string _msg);

  void writeLogToDisk();
  void writeLogToDisk(std::stringstream& _msgLog);
  void writeLogToDisk(std::string _msg);
};

inline Log::Log()
{
  outputFilename = "untitled.log";
  logMsg = "";
}

inline void Log::addLog(std::string _msg)
{
  logMsg += _msg;
}

inline void Log::addLog(std::stringstream& _msgLog)
{
  addLog(_msgLog.str());
  _msgLog.str("");
}

inline void Log::writeLogToDisk(std::string _msg)
{
  logMsg += _msg;
  writeLogToDisk();
}

inline void Log::writeLogToDisk(std::stringstream& _msgLog)
{
  writeLogToDisk(_msgLog.str());
  _msgLog.str("");
}

inline void Log::writeLogToDisk()
{
#ifdef OUTPUT_GIO_LOGS
  std::ofstream outputFile(outputFilename.c_str(), std::ios::out);
  outputFile << logMsg;
  outputFile.close();
#endif
}

} // GIOPvPlugin namespace

#endif
