// python wrapper for vtkGhostCellsGenerator
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkGhostCellsGenerator.h"

#if defined(PYTHON_PACKAGE)
#define PYTHON_PACKAGE_SCOPE PYTHON_PACKAGE "."
#else
#define PYTHON_PACKAGE_SCOPE
#endif

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkGhostCellsGenerator(PyObject *dict); }
extern "C" { PyObject *PyvtkGhostCellsGenerator_ClassNew(); }


static const char *PyvtkGhostCellsGenerator_Doc =
  "vtkGhostCellsGenerator - Computes ghost cells on vtkCompositeDataSet\ninputs\n\n"
  "Superclass: vtkPassInputTypeAlgorithm\n\n"
  "This filter computes ghost cells between data sets of same types in a\n"
  "`vtkCompositeDataSet`. For example, a `vtkImageData` inside a\n"
  "`vtkCompositeDataSet` will send and receive ghosts only to and from\n"
  "other `vtkImageData`.\n\n"
  "If the input is a `vtkPartitionedDataSetCollection`, then ghosts are\n"
  "computed per partitioned data set. In other words, ghost are not\n"
  "computed between 2 `vtkDataSet` belonging to 2 different\n"
  "`vtkPartitionedDataSet`, even if they are adjacent.\n\n"
  "If `BuildIfRequired` is set to true (which is by default), then the\n"
  "filter will compute ghost based on the value being returned by\n"
  "`vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS()`\n"
  "in the downstream streaming pipeline. If not (i.e. `BuildIfRequired`\n"
  "is off), then the max between this latter value and\n"
  "`NumberOfGhostLayers` is being used.\n\n"
  "If the input is composed of some data sets already owning ghosts,\n"
  "those ghosts are removed from the output and are recomputed. Ghosts\n"
  "in the input are as if they didn't exist. A ghost cell is to be\n"
  "peeled off if it holds the `CELLDUPLICATE` flag in its ghost bit\n"
  "mask. Similarly, each generated ghost cells from this filter is\n"
  "tagged with `CELLDUPLICATE`, in addition of other tags that could be\n"
  "set (`HIDDENCELL` for instance).\n\n"
  "If the input is a `vtkUnstructuredGrid`, if the input `vtkPointData`\n"
  "has global ids, then the values of those global ids are used instead\n"
  "of point position in 3D to connect 2 partitions. If not, point\n"
  "position of the outer surface are used to connect them. The precision\n"
  "of such connection is done using numeric precision of the input\n"
  "coordinates.\n\n"
  "@warning If an input already holds ghosts, the input ghost cells\n"
  "    should be tagged as\n"
  "`CELLDUPLICATE` in order for this filter to work properly.\n\n"
  "ote Currently,`vtkImageData`, `vtkRectilinearGrid`,\n"
  "`vtkStructuredGrid` and `vtkUnstructuredGrid` are implemented.\n\n";


static PyObject *
PyvtkGhostCellsGenerator_IsTypeOf(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkGhostCellsGenerator::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGhostCellsGenerator_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGhostCellsGenerator *op = static_cast<vtkGhostCellsGenerator *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkGhostCellsGenerator::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGhostCellsGenerator_SafeDownCast(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkGhostCellsGenerator *tempr = vtkGhostCellsGenerator::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGhostCellsGenerator_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGhostCellsGenerator *op = static_cast<vtkGhostCellsGenerator *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkGhostCellsGenerator *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkGhostCellsGenerator::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(nullptr);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkGhostCellsGenerator_GetNumberOfGenerationsFromBaseType(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetNumberOfGenerationsFromBaseType");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkGhostCellsGenerator::GetNumberOfGenerationsFromBaseType(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGhostCellsGenerator_GetNumberOfGenerationsFromBase(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGenerationsFromBase");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGhostCellsGenerator *op = static_cast<vtkGhostCellsGenerator *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfGenerationsFromBase(temp0) :
      op->vtkGhostCellsGenerator::GetNumberOfGenerationsFromBase(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGhostCellsGenerator_SetController(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetController");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGhostCellsGenerator *op = static_cast<vtkGhostCellsGenerator *>(vp);

  vtkMultiProcessController *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkMultiProcessController"))
  {
    if (ap.IsBound())
    {
      op->SetController(temp0);
    }
    else
    {
      op->vtkGhostCellsGenerator::SetController(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGhostCellsGenerator_GetController(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetController");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGhostCellsGenerator *op = static_cast<vtkGhostCellsGenerator *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkMultiProcessController *tempr = (ap.IsBound() ?
      op->GetController() :
      op->vtkGhostCellsGenerator::GetController());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGhostCellsGenerator_Initialize(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "Initialize");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGhostCellsGenerator *op = static_cast<vtkGhostCellsGenerator *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->Initialize();
    }
    else
    {
      op->vtkGhostCellsGenerator::Initialize();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGhostCellsGenerator_SetBuildIfRequired(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetBuildIfRequired");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGhostCellsGenerator *op = static_cast<vtkGhostCellsGenerator *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetBuildIfRequired(temp0);
    }
    else
    {
      op->vtkGhostCellsGenerator::SetBuildIfRequired(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGhostCellsGenerator_GetBuildIfRequired(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetBuildIfRequired");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGhostCellsGenerator *op = static_cast<vtkGhostCellsGenerator *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetBuildIfRequired() :
      op->vtkGhostCellsGenerator::GetBuildIfRequired());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGhostCellsGenerator_BuildIfRequiredOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "BuildIfRequiredOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGhostCellsGenerator *op = static_cast<vtkGhostCellsGenerator *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->BuildIfRequiredOn();
    }
    else
    {
      op->vtkGhostCellsGenerator::BuildIfRequiredOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGhostCellsGenerator_BuildIfRequiredOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "BuildIfRequiredOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGhostCellsGenerator *op = static_cast<vtkGhostCellsGenerator *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->BuildIfRequiredOff();
    }
    else
    {
      op->vtkGhostCellsGenerator::BuildIfRequiredOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGhostCellsGenerator_GetNumberOfGhostLayers(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGhostLayers");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGhostCellsGenerator *op = static_cast<vtkGhostCellsGenerator *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfGhostLayers() :
      op->vtkGhostCellsGenerator::GetNumberOfGhostLayers());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGhostCellsGenerator_SetNumberOfGhostLayers(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetNumberOfGhostLayers");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGhostCellsGenerator *op = static_cast<vtkGhostCellsGenerator *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetNumberOfGhostLayers(temp0);
    }
    else
    {
      op->vtkGhostCellsGenerator::SetNumberOfGhostLayers(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkGhostCellsGenerator_GetNumberOfGhostLayersMinValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGhostLayersMinValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGhostCellsGenerator *op = static_cast<vtkGhostCellsGenerator *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfGhostLayersMinValue() :
      op->vtkGhostCellsGenerator::GetNumberOfGhostLayersMinValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkGhostCellsGenerator_GetNumberOfGhostLayersMaxValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGhostLayersMaxValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkGhostCellsGenerator *op = static_cast<vtkGhostCellsGenerator *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfGhostLayersMaxValue() :
      op->vtkGhostCellsGenerator::GetNumberOfGhostLayersMaxValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}

static PyMethodDef PyvtkGhostCellsGenerator_Methods[] = {
  {"IsTypeOf", PyvtkGhostCellsGenerator_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkGhostCellsGenerator_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkGhostCellsGenerator_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkGhostCellsGenerator\nC++: static vtkGhostCellsGenerator *SafeDownCast(vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkGhostCellsGenerator_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkGhostCellsGenerator\nC++: vtkGhostCellsGenerator *NewInstance()\n\n"},
  {"GetNumberOfGenerationsFromBaseType", PyvtkGhostCellsGenerator_GetNumberOfGenerationsFromBaseType, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBaseType(string) -> int\nC++: static vtkIdType GetNumberOfGenerationsFromBaseType(\n    const char *type)\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"GetNumberOfGenerationsFromBase", PyvtkGhostCellsGenerator_GetNumberOfGenerationsFromBase, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBase(string) -> int\nC++: vtkIdType GetNumberOfGenerationsFromBase(const char *type)\n    override;\n\nGiven the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SetController", PyvtkGhostCellsGenerator_SetController, METH_VARARGS,
   "V.SetController(vtkMultiProcessController)\nC++: void SetController(vtkMultiProcessController *)\n\nGet/Set the controller to use. By default\nvtkMultiProcessController::GlobalController will be used.\n"},
  {"GetController", PyvtkGhostCellsGenerator_GetController, METH_VARARGS,
   "V.GetController() -> vtkMultiProcessController\nC++: virtual vtkMultiProcessController *GetController()\n\n"},
  {"Initialize", PyvtkGhostCellsGenerator_Initialize, METH_VARARGS,
   "V.Initialize()\nC++: virtual void Initialize()\n\n"},
  {"SetBuildIfRequired", PyvtkGhostCellsGenerator_SetBuildIfRequired, METH_VARARGS,
   "V.SetBuildIfRequired(bool)\nC++: virtual void SetBuildIfRequired(bool _arg)\n\nSpecify if the filter must generate the ghost cells only if\nrequired by the pipeline. If false, ghost cells are computed even\nif they are not required. Default is TRUE.\n"},
  {"GetBuildIfRequired", PyvtkGhostCellsGenerator_GetBuildIfRequired, METH_VARARGS,
   "V.GetBuildIfRequired() -> bool\nC++: virtual bool GetBuildIfRequired()\n\n"},
  {"BuildIfRequiredOn", PyvtkGhostCellsGenerator_BuildIfRequiredOn, METH_VARARGS,
   "V.BuildIfRequiredOn()\nC++: virtual void BuildIfRequiredOn()\n\n"},
  {"BuildIfRequiredOff", PyvtkGhostCellsGenerator_BuildIfRequiredOff, METH_VARARGS,
   "V.BuildIfRequiredOff()\nC++: virtual void BuildIfRequiredOff()\n\n"},
  {"GetNumberOfGhostLayers", PyvtkGhostCellsGenerator_GetNumberOfGhostLayers, METH_VARARGS,
   "V.GetNumberOfGhostLayers() -> int\nC++: virtual int GetNumberOfGhostLayers()\n\nWhen BuildIfRequired is `false`, this can be used to set the\nnumber of ghost layers to generate. Note, if the downstream\npipeline requests more ghost levels than the number specified\nhere, then the filter will generate those extra ghost levels as\nneeded. Accepted values are in the interval [1, VTK_INT_MAX].\n"},
  {"SetNumberOfGhostLayers", PyvtkGhostCellsGenerator_SetNumberOfGhostLayers, METH_VARARGS,
   "V.SetNumberOfGhostLayers(int)\nC++: virtual void SetNumberOfGhostLayers(int _arg)\n\n"},
  {"GetNumberOfGhostLayersMinValue", PyvtkGhostCellsGenerator_GetNumberOfGhostLayersMinValue, METH_VARARGS,
   "V.GetNumberOfGhostLayersMinValue() -> int\nC++: virtual int GetNumberOfGhostLayersMinValue()\n\n"},
  {"GetNumberOfGhostLayersMaxValue", PyvtkGhostCellsGenerator_GetNumberOfGhostLayersMaxValue, METH_VARARGS,
   "V.GetNumberOfGhostLayersMaxValue() -> int\nC++: virtual int GetNumberOfGhostLayersMaxValue()\n\n"},
  {nullptr, nullptr, 0, nullptr}
};

#ifdef VTK_PYTHON_NEEDS_DEPRECATION_WARNING_SUPPRESSION
#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
#endif

static PyTypeObject PyvtkGhostCellsGenerator_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  PYTHON_PACKAGE_SCOPE "vtkFiltersParallelDIY2.vtkGhostCellsGenerator", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
#if PY_VERSION_HEX >= 0x03080000
  0, // tp_vectorcall_offset
#else
  nullptr, // tp_print
#endif
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkGhostCellsGenerator_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkGhostCellsGenerator_StaticNew()
{
  return vtkGhostCellsGenerator::New();
}

PyObject *PyvtkGhostCellsGenerator_ClassNew()
{
  PyTypeObject *pytype = PyVTKClass_Add(
    &PyvtkGhostCellsGenerator_Type, PyvtkGhostCellsGenerator_Methods,
    "vtkGhostCellsGenerator",
 &PyvtkGhostCellsGenerator_StaticNew);

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#ifndef VTK_PY3K
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = vtkPythonUtil::FindClassTypeObject("vtkPassInputTypeAlgorithm");

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkGhostCellsGenerator(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkGhostCellsGenerator_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkGhostCellsGenerator", o) != 0)
  {
    Py_DECREF(o);
  }

}

