// python wrapper for vtkPUnstructuredGridGhostCellsGenerator
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkPUnstructuredGridGhostCellsGenerator.h"

#if defined(PYTHON_PACKAGE)
#define PYTHON_PACKAGE_SCOPE PYTHON_PACKAGE "."
#else
#define PYTHON_PACKAGE_SCOPE
#endif

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkPUnstructuredGridGhostCellsGenerator(PyObject *dict); }
extern "C" { PyObject *PyvtkPUnstructuredGridGhostCellsGenerator_ClassNew(); }


static const char *PyvtkPUnstructuredGridGhostCellsGenerator_Doc =
  "vtkPUnstructuredGridGhostCellsGenerator - Builds ghost cells for a\n distributed unstructured grid dataset.\n\n"
  "Superclass: vtkUnstructuredGridGhostCellsGenerator\n\n"
  "This filter generate ghost cells for distributed a unstructured grid\n"
  "in parallel - using MPI asynchronous communications. The filter can\n"
  "take benefit of the input grid point global ids to perform.\n\n"
  "@warning\n"
  " \n"
  "   A step of 'all reduce' (each process send/receive grid bounds\n"
  "to/from\n"
  "        all other processes).\n"
  "   The code currently assumes one grid per rank. \n"
  "   PointData and CellData must match across partitions/processes. \n"
  " \n\n"
  "@sa\n"
  "vtkDistributedDataFilter\n\n"
  "@par Thanks: This filter has been developed by Joachim Pouderoux,\n"
  "Kitware SAS 2015.\n\n"
  "@par Thanks: This filter was expanded to compute multiple ghost\n"
  "layers by Boonthanome Nouanesengsy and John Patchett, Los Alamos\n"
  "National Laboratory 2016. These changes are based on the paper: M.\n"
  "Patchett, John & Nouanesengesy, Boonthanome & Pouderoux, Joachim &\n"
  "Ahrens, James & Hagen, Hans. (2017). \"Parallel Multi-Level Ghost Cell Generation for Distributed Unstructured\n"
  "Grids\" which was presented at LDAV 2017 (The 7th IEEE Symposium on\n"
  "Large Data Analysis and Visualization), At Phoenix, AZ, USA.\n\n"
  "@par Thanks:\n"
  "************************************************\n\n"
  "@par Thanks: This filter uses different algorithms when obtaining the\n"
  "first layer of ghost cells and getting subsequent layers.\n\n"
  "@par Thanks: First ghost cell layer algorithm:\n"
  "- each proc obtains surface points using the surface filter\n"
  "- share bounds to determine potential neighbor processes\n"
  "- share surface points with each potential neighbors\n"
  "- for each neighbor proc, look at their points, and see if any points\n"
  "  match any of your local points\n"
  "- for each matching point, find all local cells which use those\n"
  "  points, and send those cells to that proc. mark the cells that were\n"
  "sent (used for later ghost layers)\n"
  "- receive all cells sent to you, and merge everything together\n\n"
  "@par Thanks: Subsequent ghost layers\n"
  "- for each cell that was sent last round, find all other local cells\n"
  "  which border these cells. 'local cells' also includes all ghost\n"
  "  cells which i have. send these cells to the same proc, and mark\n"
  "  them as sent last round\n"
  "- receive all cells sent to you, and merge everything together\n"
  "- if another layer is needed, repeat\n\n";


static PyObject *
PyvtkPUnstructuredGridGhostCellsGenerator_IsTypeOf(PyObject * /*unused*/, PyObject *args)
{
  PyErr_WarnEx(PyExc_DeprecationWarning,
    "Call to deprecated class vtkPUnstructuredGridGhostCellsGenerator."
    " (" "Use vtkGhostCellsGenerator instead" ")"
    " -- Deprecated since version " "9.1.0" ".", 1);

  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkPUnstructuredGridGhostCellsGenerator::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPUnstructuredGridGhostCellsGenerator_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPUnstructuredGridGhostCellsGenerator *op = static_cast<vtkPUnstructuredGridGhostCellsGenerator *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkPUnstructuredGridGhostCellsGenerator::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPUnstructuredGridGhostCellsGenerator_SafeDownCast(PyObject * /*unused*/, PyObject *args)
{
  PyErr_WarnEx(PyExc_DeprecationWarning,
    "Call to deprecated class vtkPUnstructuredGridGhostCellsGenerator."
    " (" "Use vtkGhostCellsGenerator instead" ")"
    " -- Deprecated since version " "9.1.0" ".", 1);

  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkPUnstructuredGridGhostCellsGenerator *tempr = vtkPUnstructuredGridGhostCellsGenerator::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPUnstructuredGridGhostCellsGenerator_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPUnstructuredGridGhostCellsGenerator *op = static_cast<vtkPUnstructuredGridGhostCellsGenerator *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkPUnstructuredGridGhostCellsGenerator *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkPUnstructuredGridGhostCellsGenerator::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(nullptr);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkPUnstructuredGridGhostCellsGenerator_GetNumberOfGenerationsFromBaseType(PyObject * /*unused*/, PyObject *args)
{
  PyErr_WarnEx(PyExc_DeprecationWarning,
    "Call to deprecated class vtkPUnstructuredGridGhostCellsGenerator."
    " (" "Use vtkGhostCellsGenerator instead" ")"
    " -- Deprecated since version " "9.1.0" ".", 1);

  vtkPythonArgs ap(args, "GetNumberOfGenerationsFromBaseType");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkPUnstructuredGridGhostCellsGenerator::GetNumberOfGenerationsFromBaseType(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPUnstructuredGridGhostCellsGenerator_GetNumberOfGenerationsFromBase(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGenerationsFromBase");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPUnstructuredGridGhostCellsGenerator *op = static_cast<vtkPUnstructuredGridGhostCellsGenerator *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfGenerationsFromBase(temp0) :
      op->vtkPUnstructuredGridGhostCellsGenerator::GetNumberOfGenerationsFromBase(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkPUnstructuredGridGhostCellsGenerator_SetController(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetController");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPUnstructuredGridGhostCellsGenerator *op = static_cast<vtkPUnstructuredGridGhostCellsGenerator *>(vp);

  vtkMultiProcessController *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkMultiProcessController"))
  {
    if (ap.IsBound())
    {
      op->SetController(temp0);
    }
    else
    {
      op->vtkPUnstructuredGridGhostCellsGenerator::SetController(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkPUnstructuredGridGhostCellsGenerator_GetController(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetController");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkPUnstructuredGridGhostCellsGenerator *op = static_cast<vtkPUnstructuredGridGhostCellsGenerator *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkMultiProcessController *tempr = (ap.IsBound() ?
      op->GetController() :
      op->vtkPUnstructuredGridGhostCellsGenerator::GetController());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}

static PyMethodDef PyvtkPUnstructuredGridGhostCellsGenerator_Methods[] = {
  {"IsTypeOf", PyvtkPUnstructuredGridGhostCellsGenerator_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkPUnstructuredGridGhostCellsGenerator_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkPUnstructuredGridGhostCellsGenerator_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase)\n    -> vtkPUnstructuredGridGhostCellsGenerator\nC++: static vtkPUnstructuredGridGhostCellsGenerator *SafeDownCast(\n    vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkPUnstructuredGridGhostCellsGenerator_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkPUnstructuredGridGhostCellsGenerator\nC++: vtkPUnstructuredGridGhostCellsGenerator *NewInstance()\n\n"},
  {"GetNumberOfGenerationsFromBaseType", PyvtkPUnstructuredGridGhostCellsGenerator_GetNumberOfGenerationsFromBaseType, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBaseType(string) -> int\nC++: static vtkIdType GetNumberOfGenerationsFromBaseType(\n    const char *type)\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"GetNumberOfGenerationsFromBase", PyvtkPUnstructuredGridGhostCellsGenerator_GetNumberOfGenerationsFromBase, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBase(string) -> int\nC++: vtkIdType GetNumberOfGenerationsFromBase(const char *type)\n    override;\n\nGiven the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SetController", PyvtkPUnstructuredGridGhostCellsGenerator_SetController, METH_VARARGS,
   "V.SetController(vtkMultiProcessController)\nC++: void SetController(vtkMultiProcessController *c)\n\nSet/Get the MPI multi process controller object.\n"},
  {"GetController", PyvtkPUnstructuredGridGhostCellsGenerator_GetController, METH_VARARGS,
   "V.GetController() -> vtkMultiProcessController\nC++: virtual vtkMultiProcessController *GetController()\n\n"},
  {nullptr, nullptr, 0, nullptr}
};

#ifdef VTK_PYTHON_NEEDS_DEPRECATION_WARNING_SUPPRESSION
#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
#endif

static PyTypeObject PyvtkPUnstructuredGridGhostCellsGenerator_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  PYTHON_PACKAGE_SCOPE "vtkFiltersParallelGeometry.vtkPUnstructuredGridGhostCellsGenerator", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
#if PY_VERSION_HEX >= 0x03080000
  0, // tp_vectorcall_offset
#else
  nullptr, // tp_print
#endif
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkPUnstructuredGridGhostCellsGenerator_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkPUnstructuredGridGhostCellsGenerator_StaticNew()
{
  PyErr_WarnEx(PyExc_DeprecationWarning,
    "Call to deprecated class vtkPUnstructuredGridGhostCellsGenerator."
    " (" "Use vtkGhostCellsGenerator instead" ")"
    " -- Deprecated since version " "9.1.0" ".", 1);

  return vtkPUnstructuredGridGhostCellsGenerator::New();
}

PyObject *PyvtkPUnstructuredGridGhostCellsGenerator_ClassNew()
{
  PyTypeObject *pytype = PyVTKClass_Add(
    &PyvtkPUnstructuredGridGhostCellsGenerator_Type, PyvtkPUnstructuredGridGhostCellsGenerator_Methods,
    "vtkPUnstructuredGridGhostCellsGenerator",
 &PyvtkPUnstructuredGridGhostCellsGenerator_StaticNew);

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#ifndef VTK_PY3K
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = vtkPythonUtil::FindClassTypeObject("vtkUnstructuredGridGhostCellsGenerator");

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkPUnstructuredGridGhostCellsGenerator(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkPUnstructuredGridGhostCellsGenerator_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkPUnstructuredGridGhostCellsGenerator", o) != 0)
  {
    Py_DECREF(o);
  }

}

