// python wrapper for vtkConduitArrayUtilities
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkSmartPointer.h"
#include "vtkSmartPointer.h"
#include "vtkConduitArrayUtilities.h"

#if defined(PYTHON_PACKAGE)
#define PYTHON_PACKAGE_SCOPE PYTHON_PACKAGE "."
#else
#define PYTHON_PACKAGE_SCOPE
#endif

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkConduitArrayUtilities(PyObject *dict); }
extern "C" { PyObject *PyvtkConduitArrayUtilities_ClassNew(); }


static const char *PyvtkConduitArrayUtilities_Doc =
  "vtkConduitArrayUtilities - helper to convert Conduit arrays to VTK\narrays.\n\n"
  "Superclass: vtkObject\n\n"
  "@ingroup Insitu\n\n"
  "vtkConduitArrayUtilities is intended to convert Conduit nodes\n"
  "satisfying the `mcarray` protocol to VTK arrays. It uses zero-copy,\n"
  "as much as possible. Currently implementation fails if zero-copy is\n"
  "not possible. In future, that may be changed to do a deep-copy (with\n"
  "appropriate warnings) if necessary.\n\n"
  "This is primarily designed for use by vtkConduitSource.\n\n";


static PyObject *
PyvtkConduitArrayUtilities_IsTypeOf(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkConduitArrayUtilities::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkConduitArrayUtilities_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkConduitArrayUtilities *op = static_cast<vtkConduitArrayUtilities *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkConduitArrayUtilities::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkConduitArrayUtilities_SafeDownCast(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkConduitArrayUtilities *tempr = vtkConduitArrayUtilities::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkConduitArrayUtilities_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkConduitArrayUtilities *op = static_cast<vtkConduitArrayUtilities *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkConduitArrayUtilities *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkConduitArrayUtilities::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(nullptr);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkConduitArrayUtilities_GetNumberOfGenerationsFromBaseType(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetNumberOfGenerationsFromBaseType");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkConduitArrayUtilities::GetNumberOfGenerationsFromBaseType(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkConduitArrayUtilities_GetNumberOfGenerationsFromBase(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGenerationsFromBase");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkConduitArrayUtilities *op = static_cast<vtkConduitArrayUtilities *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfGenerationsFromBase(temp0) :
      op->vtkConduitArrayUtilities::GetNumberOfGenerationsFromBase(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkConduitArrayUtilities_MCArrayToVTKArray_s1(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "MCArrayToVTKArray");

  void  *temp0 = nullptr;
  Py_buffer pbuf0 = VTK_PYBUFFER_INITIALIZER;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetBuffer(temp0, &pbuf0))
  {
    vtkSmartPointer<vtkDataArray> tempr = vtkConduitArrayUtilities::MCArrayToVTKArray(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildSpecialObject(&tempr, "vtkSmartPointer_I12vtkDataArrayE");
    }
  }

  if (pbuf0.obj != nullptr)
  {
    PyBuffer_Release(&pbuf0);
  }
  return result;
}

static PyObject *
PyvtkConduitArrayUtilities_MCArrayToVTKArray_s2(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "MCArrayToVTKArray");

  void  *temp0 = nullptr;
  Py_buffer pbuf0 = VTK_PYBUFFER_INITIALIZER;
  std::string temp1;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(2) &&
      ap.GetBuffer(temp0, &pbuf0) &&
      ap.GetValue(temp1))
  {
    vtkSmartPointer<vtkDataArray> tempr = vtkConduitArrayUtilities::MCArrayToVTKArray(temp0, temp1);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildSpecialObject(&tempr, "vtkSmartPointer_I12vtkDataArrayE");
    }
  }

  if (pbuf0.obj != nullptr)
  {
    PyBuffer_Release(&pbuf0);
  }
  return result;
}

static PyObject *
PyvtkConduitArrayUtilities_MCArrayToVTKArray(PyObject *self, PyObject *args)
{
  int nargs = vtkPythonArgs::GetArgCount(args);

  switch(nargs)
  {
    case 1:
      return PyvtkConduitArrayUtilities_MCArrayToVTKArray_s1(self, args);
    case 2:
      return PyvtkConduitArrayUtilities_MCArrayToVTKArray_s2(self, args);
  }

  vtkPythonArgs::ArgCountError(nargs, "MCArrayToVTKArray");
  return nullptr;
}


static PyObject *
PyvtkConduitArrayUtilities_MCArrayToVTKCellArray(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "MCArrayToVTKCellArray");

  int temp0;
  void  *temp1 = nullptr;
  Py_buffer pbuf1 = VTK_PYBUFFER_INITIALIZER;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetBuffer(temp1, &pbuf1))
  {
    vtkSmartPointer<vtkCellArray> tempr = vtkConduitArrayUtilities::MCArrayToVTKCellArray(temp0, temp1);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildSpecialObject(&tempr, "vtkSmartPointer_I12vtkCellArrayE");
    }
  }

  if (pbuf1.obj != nullptr)
  {
    PyBuffer_Release(&pbuf1);
  }
  return result;
}


static PyObject *
PyvtkConduitArrayUtilities_SetNumberOfComponents(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "SetNumberOfComponents");

  vtkDataArray *temp0 = nullptr;
  int temp1;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(2) &&
      ap.GetVTKObject(temp0, "vtkDataArray") &&
      ap.GetValue(temp1))
  {
    vtkSmartPointer<vtkDataArray> tempr = vtkConduitArrayUtilities::SetNumberOfComponents(temp0, temp1);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildSpecialObject(&tempr, "vtkSmartPointer_I12vtkDataArrayE");
    }
  }

  return result;
}


static PyObject *
PyvtkConduitArrayUtilities_O2MRelationToVTKCellArray(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "O2MRelationToVTKCellArray");

  void  *temp0 = nullptr;
  Py_buffer pbuf0 = VTK_PYBUFFER_INITIALIZER;
  std::string temp1;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(2) &&
      ap.GetBuffer(temp0, &pbuf0) &&
      ap.GetValue(temp1))
  {
    vtkSmartPointer<vtkCellArray> tempr = vtkConduitArrayUtilities::O2MRelationToVTKCellArray(temp0, temp1);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildSpecialObject(&tempr, "vtkSmartPointer_I12vtkCellArrayE");
    }
  }

  if (pbuf0.obj != nullptr)
  {
    PyBuffer_Release(&pbuf0);
  }
  return result;
}

static PyMethodDef PyvtkConduitArrayUtilities_Methods[] = {
  {"IsTypeOf", PyvtkConduitArrayUtilities_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkConduitArrayUtilities_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkConduitArrayUtilities_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkConduitArrayUtilities\nC++: static vtkConduitArrayUtilities *SafeDownCast(\n    vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkConduitArrayUtilities_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkConduitArrayUtilities\nC++: vtkConduitArrayUtilities *NewInstance()\n\n"},
  {"GetNumberOfGenerationsFromBaseType", PyvtkConduitArrayUtilities_GetNumberOfGenerationsFromBaseType, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBaseType(string) -> int\nC++: static vtkIdType GetNumberOfGenerationsFromBaseType(\n    const char *type)\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"GetNumberOfGenerationsFromBase", PyvtkConduitArrayUtilities_GetNumberOfGenerationsFromBase, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBase(string) -> int\nC++: vtkIdType GetNumberOfGenerationsFromBase(const char *type)\n    override;\n\nGiven the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"MCArrayToVTKArray", PyvtkConduitArrayUtilities_MCArrayToVTKArray, METH_VARARGS,
   "V.MCArrayToVTKArray(void) -> vtkSmartPointer_I12vtkDataArrayE\nC++: static vtkSmartPointer<vtkDataArray> MCArrayToVTKArray(\n    const conduit_node *mcarray)\nV.MCArrayToVTKArray(void, string)\n    -> vtkSmartPointer_I12vtkDataArrayE\nC++: static vtkSmartPointer<vtkDataArray> MCArrayToVTKArray(\n    const conduit_node *mcarray, const std::string &arrayname)\n\nReturns a vtkDataArray from a conduit node in the conduit mcarray\nprotocol.\n"},
  {"MCArrayToVTKCellArray", PyvtkConduitArrayUtilities_MCArrayToVTKCellArray, METH_VARARGS,
   "V.MCArrayToVTKCellArray(int, void)\n    -> vtkSmartPointer_I12vtkCellArrayE\nC++: static vtkSmartPointer<vtkCellArray> MCArrayToVTKCellArray(\n    vtkIdType cellSize, const conduit_node *mcarray)\n\nConverts an mcarray to vtkCellArray.\n\nThis may reinterpret unsigned array as signed arrays to avoid\ndeep-copying of data to match data type expected by vtkCellArray\nAPI.\n"},
  {"SetNumberOfComponents", PyvtkConduitArrayUtilities_SetNumberOfComponents, METH_VARARGS,
   "V.SetNumberOfComponents(vtkDataArray, int)\n    -> vtkSmartPointer_I12vtkDataArrayE\nC++: static vtkSmartPointer<vtkDataArray> SetNumberOfComponents(\n    vtkDataArray *array, int num_components)\n\nIf the number of components in the array does not match the\ntarget, a new array is created.\n"},
  {"O2MRelationToVTKCellArray", PyvtkConduitArrayUtilities_O2MRelationToVTKCellArray, METH_VARARGS,
   "V.O2MRelationToVTKCellArray(void, string)\n    -> vtkSmartPointer_I12vtkCellArrayE\nC++: static vtkSmartPointer<vtkCellArray> O2MRelationToVTKCellArray(\n    const conduit_node *o2mrelation, const std::string &leafname)\n\nRead a O2MRelation element\n"},
  {nullptr, nullptr, 0, nullptr}
};

#ifdef VTK_PYTHON_NEEDS_DEPRECATION_WARNING_SUPPRESSION
#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
#endif

static PyTypeObject PyvtkConduitArrayUtilities_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  PYTHON_PACKAGE_SCOPE "vtkPVVTKExtensionsConduit.vtkConduitArrayUtilities", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
#if PY_VERSION_HEX >= 0x03080000
  0, // tp_vectorcall_offset
#else
  nullptr, // tp_print
#endif
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkConduitArrayUtilities_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkConduitArrayUtilities_StaticNew()
{
  return vtkConduitArrayUtilities::New();
}

PyObject *PyvtkConduitArrayUtilities_ClassNew()
{
  PyTypeObject *pytype = PyVTKClass_Add(
    &PyvtkConduitArrayUtilities_Type, PyvtkConduitArrayUtilities_Methods,
    "vtkConduitArrayUtilities",
 &PyvtkConduitArrayUtilities_StaticNew);

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#ifndef VTK_PY3K
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = vtkPythonUtil::FindClassTypeObject("vtkObject");

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkConduitArrayUtilities(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkConduitArrayUtilities_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkConduitArrayUtilities", o) != 0)
  {
    Py_DECREF(o);
  }

}

