// python wrapper for vtkConduitSource
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkConduitSource.h"

#if defined(PYTHON_PACKAGE)
#define PYTHON_PACKAGE_SCOPE PYTHON_PACKAGE "."
#else
#define PYTHON_PACKAGE_SCOPE
#endif

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkConduitSource(PyObject *dict); }
extern "C" { PyObject *PyvtkConduitSource_ClassNew(); }


static const char *PyvtkConduitSource_Doc =
  "vtkConduitSource - data source for Conduit Mesh Blueprint.\n\n"
  "Superclass: vtkDataObjectAlgorithm\n\n"
  "@ingroup Insitu\n\n"
  "vtkConduitSource is a data source that processes a Conduit node using\n"
  "[Conduit Mesh\n"
  "Blueprint](https://llnl-conduit.readthedocs.io/en/latest/blueprint_mes\n"
  "h.html#) to describe computational mesh and associated meta-data.\n\n"
  "vtkConduitSource currently produces a `vtkParitionedDataSet` or\n"
  "`vtkPartitionedDataSetCollection`\n\n"
  "@sa vtkConduitArrayUtilities\n\n";


static PyObject *
PyvtkConduitSource_IsTypeOf(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkConduitSource::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkConduitSource_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkConduitSource *op = static_cast<vtkConduitSource *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkConduitSource::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkConduitSource_SafeDownCast(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkConduitSource *tempr = vtkConduitSource::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkConduitSource_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkConduitSource *op = static_cast<vtkConduitSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkConduitSource *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkConduitSource::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(nullptr);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkConduitSource_GetNumberOfGenerationsFromBaseType(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetNumberOfGenerationsFromBaseType");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkConduitSource::GetNumberOfGenerationsFromBaseType(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkConduitSource_GetNumberOfGenerationsFromBase(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGenerationsFromBase");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkConduitSource *op = static_cast<vtkConduitSource *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfGenerationsFromBase(temp0) :
      op->vtkConduitSource::GetNumberOfGenerationsFromBase(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkConduitSource_SetUseMultiMeshProtocol(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetUseMultiMeshProtocol");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkConduitSource *op = static_cast<vtkConduitSource *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetUseMultiMeshProtocol(temp0);
    }
    else
    {
      op->vtkConduitSource::SetUseMultiMeshProtocol(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkConduitSource_GetUseMultiMeshProtocol(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetUseMultiMeshProtocol");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkConduitSource *op = static_cast<vtkConduitSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetUseMultiMeshProtocol() :
      op->vtkConduitSource::GetUseMultiMeshProtocol());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkConduitSource_UseMultiMeshProtocolOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "UseMultiMeshProtocolOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkConduitSource *op = static_cast<vtkConduitSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->UseMultiMeshProtocolOn();
    }
    else
    {
      op->vtkConduitSource::UseMultiMeshProtocolOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkConduitSource_UseMultiMeshProtocolOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "UseMultiMeshProtocolOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkConduitSource *op = static_cast<vtkConduitSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->UseMultiMeshProtocolOff();
    }
    else
    {
      op->vtkConduitSource::UseMultiMeshProtocolOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkConduitSource_SetNode(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetNode");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkConduitSource *op = static_cast<vtkConduitSource *>(vp);

  void  *temp0 = nullptr;
  Py_buffer pbuf0 = VTK_PYBUFFER_INITIALIZER;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetBuffer(temp0, &pbuf0))
  {
    if (ap.IsBound())
    {
      op->SetNode(temp0);
    }
    else
    {
      op->vtkConduitSource::SetNode(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  if (pbuf0.obj != nullptr)
  {
    PyBuffer_Release(&pbuf0);
  }
  return result;
}


static PyObject *
PyvtkConduitSource_SetGlobalFieldsNode(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetGlobalFieldsNode");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkConduitSource *op = static_cast<vtkConduitSource *>(vp);

  void  *temp0 = nullptr;
  Py_buffer pbuf0 = VTK_PYBUFFER_INITIALIZER;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetBuffer(temp0, &pbuf0))
  {
    if (ap.IsBound())
    {
      op->SetGlobalFieldsNode(temp0);
    }
    else
    {
      op->vtkConduitSource::SetGlobalFieldsNode(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  if (pbuf0.obj != nullptr)
  {
    PyBuffer_Release(&pbuf0);
  }
  return result;
}


static PyObject *
PyvtkConduitSource_SetAssemblyNode(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetAssemblyNode");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkConduitSource *op = static_cast<vtkConduitSource *>(vp);

  void  *temp0 = nullptr;
  Py_buffer pbuf0 = VTK_PYBUFFER_INITIALIZER;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetBuffer(temp0, &pbuf0))
  {
    if (ap.IsBound())
    {
      op->SetAssemblyNode(temp0);
    }
    else
    {
      op->vtkConduitSource::SetAssemblyNode(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  if (pbuf0.obj != nullptr)
  {
    PyBuffer_Release(&pbuf0);
  }
  return result;
}

static PyMethodDef PyvtkConduitSource_Methods[] = {
  {"IsTypeOf", PyvtkConduitSource_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkConduitSource_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkConduitSource_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkConduitSource\nC++: static vtkConduitSource *SafeDownCast(vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkConduitSource_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkConduitSource\nC++: vtkConduitSource *NewInstance()\n\n"},
  {"GetNumberOfGenerationsFromBaseType", PyvtkConduitSource_GetNumberOfGenerationsFromBaseType, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBaseType(string) -> int\nC++: static vtkIdType GetNumberOfGenerationsFromBaseType(\n    const char *type)\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"GetNumberOfGenerationsFromBase", PyvtkConduitSource_GetNumberOfGenerationsFromBase, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBase(string) -> int\nC++: vtkIdType GetNumberOfGenerationsFromBase(const char *type)\n    override;\n\nGiven the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SetUseMultiMeshProtocol", PyvtkConduitSource_SetUseMultiMeshProtocol, METH_VARARGS,
   "V.SetUseMultiMeshProtocol(bool)\nC++: virtual void SetUseMultiMeshProtocol(bool _arg)\n\nvtkConduitSource supports single 'mesh' and multiple 'mesh' (aka\n'multimesh') protocols. Set this to true if the source is\nhandling multimesh (default is false).\n"},
  {"GetUseMultiMeshProtocol", PyvtkConduitSource_GetUseMultiMeshProtocol, METH_VARARGS,
   "V.GetUseMultiMeshProtocol() -> bool\nC++: virtual bool GetUseMultiMeshProtocol()\n\n"},
  {"UseMultiMeshProtocolOn", PyvtkConduitSource_UseMultiMeshProtocolOn, METH_VARARGS,
   "V.UseMultiMeshProtocolOn()\nC++: virtual void UseMultiMeshProtocolOn()\n\n"},
  {"UseMultiMeshProtocolOff", PyvtkConduitSource_UseMultiMeshProtocolOff, METH_VARARGS,
   "V.UseMultiMeshProtocolOff()\nC++: virtual void UseMultiMeshProtocolOff()\n\n"},
  {"SetNode", PyvtkConduitSource_SetNode, METH_VARARGS,
   "V.SetNode(void)\nC++: void SetNode(const conduit_node *node)\n\nGet/Set the conduit_node. This must be the node satisfying the\nConduit Mesh Blueprint.\n"},
  {"SetGlobalFieldsNode", PyvtkConduitSource_SetGlobalFieldsNode, METH_VARARGS,
   "V.SetGlobalFieldsNode(void)\nC++: void SetGlobalFieldsNode(const conduit_node *node)\n\nMechanism to add global / field-data arrays.\n\nThis is currently experimental and expected to change. It is\nexperimental since it's unclear to the developer if Conduit\nBlueprint already supports specifying global fields i.e. without\nany association. Doesn't look like it, but if it does, this\nshould be changed to directly leverage that.\n"},
  {"SetAssemblyNode", PyvtkConduitSource_SetAssemblyNode, METH_VARARGS,
   "V.SetAssemblyNode(void)\nC++: void SetAssemblyNode(const conduit_node *node)\n\nSet the node to read the assembly information from, if any.\n"},
  {nullptr, nullptr, 0, nullptr}
};

#ifdef VTK_PYTHON_NEEDS_DEPRECATION_WARNING_SUPPRESSION
#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
#endif

static PyTypeObject PyvtkConduitSource_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  PYTHON_PACKAGE_SCOPE "vtkPVVTKExtensionsConduit.vtkConduitSource", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
#if PY_VERSION_HEX >= 0x03080000
  0, // tp_vectorcall_offset
#else
  nullptr, // tp_print
#endif
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkConduitSource_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkConduitSource_StaticNew()
{
  return vtkConduitSource::New();
}

PyObject *PyvtkConduitSource_ClassNew()
{
  PyTypeObject *pytype = PyVTKClass_Add(
    &PyvtkConduitSource_Type, PyvtkConduitSource_Methods,
    "vtkConduitSource",
 &PyvtkConduitSource_StaticNew);

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#ifndef VTK_PY3K
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = vtkPythonUtil::FindClassTypeObject("vtkDataObjectAlgorithm");

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkConduitSource(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkConduitSource_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkConduitSource", o) != 0)
  {
    Py_DECREF(o);
  }

}

