// python wrapper for vtkQuerySelectionSource
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkQuerySelectionSource.h"

#if defined(PYTHON_PACKAGE)
#define PYTHON_PACKAGE_SCOPE PYTHON_PACKAGE "."
#else
#define PYTHON_PACKAGE_SCOPE
#endif

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkQuerySelectionSource(PyObject *dict); }
extern "C" { PyObject *PyvtkQuerySelectionSource_ClassNew(); }


static const char *PyvtkQuerySelectionSource_Doc =
  "vtkQuerySelectionSource - a selection source that uses a \"query\" to\ngenerate the selection.\n\n"
  "Superclass: vtkSelectionAlgorithm\n\n"
  "vtkQuerySelectionSource is a selection source that uses a \"query\" to\n"
  "generate the vtkSelection object. A query has the following form: \"TERM OPERATOR\n"
  "VALUE(s)\" eg. \"GLOBALID is_in_range (0, 10)\" here GLOBALID is the\n"
  "TERM, is_in_range is the operator and (0,10) are the values. A query\n"
  "can have additional qualifiers such as the process id, block id, amr\n"
  "level, amr block.\n\n";


static PyObject *
PyvtkQuerySelectionSource_IsTypeOf(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkQuerySelectionSource::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkQuerySelectionSource::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_SafeDownCast(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkQuerySelectionSource *tempr = vtkQuerySelectionSource::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkQuerySelectionSource *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkQuerySelectionSource::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(nullptr);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetNumberOfGenerationsFromBaseType(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetNumberOfGenerationsFromBaseType");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkQuerySelectionSource::GetNumberOfGenerationsFromBaseType(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetNumberOfGenerationsFromBase(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGenerationsFromBase");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfGenerationsFromBase(temp0) :
      op->vtkQuerySelectionSource::GetNumberOfGenerationsFromBase(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_SetController(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetController");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  vtkMultiProcessController *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkMultiProcessController"))
  {
    if (ap.IsBound())
    {
      op->SetController(temp0);
    }
    else
    {
      op->vtkQuerySelectionSource::SetController(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetController(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetController");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkMultiProcessController *tempr = (ap.IsBound() ?
      op->GetController() :
      op->vtkQuerySelectionSource::GetController());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_SetQueryString(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetQueryString");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetQueryString(temp0);
    }
    else
    {
      op->vtkQuerySelectionSource::SetQueryString(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetQueryString(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetQueryString");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    char *tempr = (ap.IsBound() ?
      op->GetQueryString() :
      op->vtkQuerySelectionSource::GetQueryString());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_SetAssemblyName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetAssemblyName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetAssemblyName(temp0);
    }
    else
    {
      op->vtkQuerySelectionSource::SetAssemblyName(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetAssemblyName(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAssemblyName");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    char *tempr = (ap.IsBound() ?
      op->GetAssemblyName() :
      op->vtkQuerySelectionSource::GetAssemblyName());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_AddSelector(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "AddSelector");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->AddSelector(temp0);
    }
    else
    {
      op->vtkQuerySelectionSource::AddSelector(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_ClearSelectors(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ClearSelectors");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ClearSelectors();
    }
    else
    {
      op->vtkQuerySelectionSource::ClearSelectors();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_SetAMRLevel(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetAMRLevel");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetAMRLevel(temp0);
    }
    else
    {
      op->vtkQuerySelectionSource::SetAMRLevel(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetAMRLevelMinValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAMRLevelMinValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetAMRLevelMinValue() :
      op->vtkQuerySelectionSource::GetAMRLevelMinValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetAMRLevelMaxValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAMRLevelMaxValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetAMRLevelMaxValue() :
      op->vtkQuerySelectionSource::GetAMRLevelMaxValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetAMRLevel(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAMRLevel");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetAMRLevel() :
      op->vtkQuerySelectionSource::GetAMRLevel());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_SetAMRIndex(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetAMRIndex");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetAMRIndex(temp0);
    }
    else
    {
      op->vtkQuerySelectionSource::SetAMRIndex(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetAMRIndexMinValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAMRIndexMinValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetAMRIndexMinValue() :
      op->vtkQuerySelectionSource::GetAMRIndexMinValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetAMRIndexMaxValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAMRIndexMaxValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetAMRIndexMaxValue() :
      op->vtkQuerySelectionSource::GetAMRIndexMaxValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetAMRIndex(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetAMRIndex");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetAMRIndex() :
      op->vtkQuerySelectionSource::GetAMRIndex());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_SetProcessID(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetProcessID");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetProcessID(temp0);
    }
    else
    {
      op->vtkQuerySelectionSource::SetProcessID(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetProcessIDMinValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetProcessIDMinValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetProcessIDMinValue() :
      op->vtkQuerySelectionSource::GetProcessIDMinValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetProcessIDMaxValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetProcessIDMaxValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetProcessIDMaxValue() :
      op->vtkQuerySelectionSource::GetProcessIDMaxValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetProcessID(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetProcessID");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetProcessID() :
      op->vtkQuerySelectionSource::GetProcessID());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_SetElementType(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetElementType");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetElementType(temp0);
    }
    else
    {
      op->vtkQuerySelectionSource::SetElementType(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetElementTypeMinValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetElementTypeMinValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetElementTypeMinValue() :
      op->vtkQuerySelectionSource::GetElementTypeMinValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetElementTypeMaxValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetElementTypeMaxValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetElementTypeMaxValue() :
      op->vtkQuerySelectionSource::GetElementTypeMaxValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetElementType(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetElementType");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetElementType() :
      op->vtkQuerySelectionSource::GetElementType());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetUserFriendlyText(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetUserFriendlyText");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetUserFriendlyText() :
      op->vtkQuerySelectionSource::GetUserFriendlyText());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_SetInverse(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetInverse");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetInverse(temp0);
    }
    else
    {
      op->vtkQuerySelectionSource::SetInverse(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetInverse(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetInverse");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetInverse() :
      op->vtkQuerySelectionSource::GetInverse());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_SetNumberOfLayers(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetNumberOfLayers");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetNumberOfLayers(temp0);
    }
    else
    {
      op->vtkQuerySelectionSource::SetNumberOfLayers(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetNumberOfLayersMinValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfLayersMinValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfLayersMinValue() :
      op->vtkQuerySelectionSource::GetNumberOfLayersMinValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetNumberOfLayersMaxValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfLayersMaxValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfLayersMaxValue() :
      op->vtkQuerySelectionSource::GetNumberOfLayersMaxValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkQuerySelectionSource_GetNumberOfLayers(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfLayers");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkQuerySelectionSource *op = static_cast<vtkQuerySelectionSource *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfLayers() :
      op->vtkQuerySelectionSource::GetNumberOfLayers());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}

static PyMethodDef PyvtkQuerySelectionSource_Methods[] = {
  {"IsTypeOf", PyvtkQuerySelectionSource_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkQuerySelectionSource_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkQuerySelectionSource_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkQuerySelectionSource\nC++: static vtkQuerySelectionSource *SafeDownCast(\n    vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkQuerySelectionSource_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkQuerySelectionSource\nC++: vtkQuerySelectionSource *NewInstance()\n\n"},
  {"GetNumberOfGenerationsFromBaseType", PyvtkQuerySelectionSource_GetNumberOfGenerationsFromBaseType, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBaseType(string) -> int\nC++: static vtkIdType GetNumberOfGenerationsFromBaseType(\n    const char *type)\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"GetNumberOfGenerationsFromBase", PyvtkQuerySelectionSource_GetNumberOfGenerationsFromBase, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBase(string) -> int\nC++: vtkIdType GetNumberOfGenerationsFromBase(const char *type)\n    override;\n\nGiven the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SetController", PyvtkQuerySelectionSource_SetController, METH_VARARGS,
   "V.SetController(vtkMultiProcessController)\nC++: void SetController(vtkMultiProcessController *)\n\nGet/Set the parallel controller. Initialized to\n`vtkMultiProcessController::GetGlobalController` in the\nconstructor.\n"},
  {"GetController", PyvtkQuerySelectionSource_GetController, METH_VARARGS,
   "V.GetController() -> vtkMultiProcessController\nC++: virtual vtkMultiProcessController *GetController()\n\nGet/Set the parallel controller. Initialized to\n`vtkMultiProcessController::GetGlobalController` in the\nconstructor.\n"},
  {"SetQueryString", PyvtkQuerySelectionSource_SetQueryString, METH_VARARGS,
   "V.SetQueryString(string)\nC++: virtual void SetQueryString(const char *_arg)\n\nSet/get the query expression string.\n"},
  {"GetQueryString", PyvtkQuerySelectionSource_GetQueryString, METH_VARARGS,
   "V.GetQueryString() -> string\nC++: virtual char *GetQueryString()\n\nSet/get the query expression string.\n"},
  {"SetAssemblyName", PyvtkQuerySelectionSource_SetAssemblyName, METH_VARARGS,
   "V.SetAssemblyName(string)\nC++: virtual void SetAssemblyName(const char *_arg)\n\nAssemblyName to choose an assembly and Selectors for that\nassembly to limit selection to specific blocks.\n"},
  {"GetAssemblyName", PyvtkQuerySelectionSource_GetAssemblyName, METH_VARARGS,
   "V.GetAssemblyName() -> string\nC++: virtual char *GetAssemblyName()\n\nAssemblyName to choose an assembly and Selectors for that\nassembly to limit selection to specific blocks.\n"},
  {"AddSelector", PyvtkQuerySelectionSource_AddSelector, METH_VARARGS,
   "V.AddSelector(string)\nC++: void AddSelector(const char *)\n\nAssemblyName to choose an assembly and Selectors for that\nassembly to limit selection to specific blocks.\n"},
  {"ClearSelectors", PyvtkQuerySelectionSource_ClearSelectors, METH_VARARGS,
   "V.ClearSelectors()\nC++: void ClearSelectors()\n\nAssemblyName to choose an assembly and Selectors for that\nassembly to limit selection to specific blocks.\n"},
  {"SetAMRLevel", PyvtkQuerySelectionSource_SetAMRLevel, METH_VARARGS,
   "V.SetAMRLevel(int)\nC++: virtual void SetAMRLevel(int _arg)\n\nGet/Set AMR level and index to use. Note, while VTK uses\n`unsigned int` for amr level and index numbers we use `int`s in\nthis API  and use -1 to indicate that no AMR level/index has been\nspecified.\n"},
  {"GetAMRLevelMinValue", PyvtkQuerySelectionSource_GetAMRLevelMinValue, METH_VARARGS,
   "V.GetAMRLevelMinValue() -> int\nC++: virtual int GetAMRLevelMinValue()\n\nGet/Set AMR level and index to use. Note, while VTK uses\n`unsigned int` for amr level and index numbers we use `int`s in\nthis API  and use -1 to indicate that no AMR level/index has been\nspecified.\n"},
  {"GetAMRLevelMaxValue", PyvtkQuerySelectionSource_GetAMRLevelMaxValue, METH_VARARGS,
   "V.GetAMRLevelMaxValue() -> int\nC++: virtual int GetAMRLevelMaxValue()\n\nGet/Set AMR level and index to use. Note, while VTK uses\n`unsigned int` for amr level and index numbers we use `int`s in\nthis API  and use -1 to indicate that no AMR level/index has been\nspecified.\n"},
  {"GetAMRLevel", PyvtkQuerySelectionSource_GetAMRLevel, METH_VARARGS,
   "V.GetAMRLevel() -> int\nC++: virtual int GetAMRLevel()\n\nGet/Set AMR level and index to use. Note, while VTK uses\n`unsigned int` for amr level and index numbers we use `int`s in\nthis API  and use -1 to indicate that no AMR level/index has been\nspecified.\n"},
  {"SetAMRIndex", PyvtkQuerySelectionSource_SetAMRIndex, METH_VARARGS,
   "V.SetAMRIndex(int)\nC++: virtual void SetAMRIndex(int _arg)\n\nGet/Set AMR level and index to use. Note, while VTK uses\n`unsigned int` for amr level and index numbers we use `int`s in\nthis API  and use -1 to indicate that no AMR level/index has been\nspecified.\n"},
  {"GetAMRIndexMinValue", PyvtkQuerySelectionSource_GetAMRIndexMinValue, METH_VARARGS,
   "V.GetAMRIndexMinValue() -> int\nC++: virtual int GetAMRIndexMinValue()\n\nGet/Set AMR level and index to use. Note, while VTK uses\n`unsigned int` for amr level and index numbers we use `int`s in\nthis API  and use -1 to indicate that no AMR level/index has been\nspecified.\n"},
  {"GetAMRIndexMaxValue", PyvtkQuerySelectionSource_GetAMRIndexMaxValue, METH_VARARGS,
   "V.GetAMRIndexMaxValue() -> int\nC++: virtual int GetAMRIndexMaxValue()\n\nGet/Set AMR level and index to use. Note, while VTK uses\n`unsigned int` for amr level and index numbers we use `int`s in\nthis API  and use -1 to indicate that no AMR level/index has been\nspecified.\n"},
  {"GetAMRIndex", PyvtkQuerySelectionSource_GetAMRIndex, METH_VARARGS,
   "V.GetAMRIndex() -> int\nC++: virtual int GetAMRIndex()\n\nGet/Set AMR level and index to use. Note, while VTK uses\n`unsigned int` for amr level and index numbers we use `int`s in\nthis API  and use -1 to indicate that no AMR level/index has been\nspecified.\n"},
  {"SetProcessID", PyvtkQuerySelectionSource_SetProcessID, METH_VARARGS,
   "V.SetProcessID(int)\nC++: virtual void SetProcessID(int _arg)\n\nGet/Set which process to limit the selection to. `-1` is treated\nas all processes.\n"},
  {"GetProcessIDMinValue", PyvtkQuerySelectionSource_GetProcessIDMinValue, METH_VARARGS,
   "V.GetProcessIDMinValue() -> int\nC++: virtual int GetProcessIDMinValue()\n\nGet/Set which process to limit the selection to. `-1` is treated\nas all processes.\n"},
  {"GetProcessIDMaxValue", PyvtkQuerySelectionSource_GetProcessIDMaxValue, METH_VARARGS,
   "V.GetProcessIDMaxValue() -> int\nC++: virtual int GetProcessIDMaxValue()\n\nGet/Set which process to limit the selection to. `-1` is treated\nas all processes.\n"},
  {"GetProcessID", PyvtkQuerySelectionSource_GetProcessID, METH_VARARGS,
   "V.GetProcessID() -> int\nC++: virtual int GetProcessID()\n\nGet/Set which process to limit the selection to. `-1` is treated\nas all processes.\n"},
  {"SetElementType", PyvtkQuerySelectionSource_SetElementType, METH_VARARGS,
   "V.SetElementType(int)\nC++: virtual void SetElementType(int _arg)\n\nSet/Get which types of elements are being selected. Accepted\nvalues are defined in `vtkDataObject::AttributeTypes`. Note,\n`vtkDataObject::FIELD` and `vtkDataObject::POINT_THEN_CELL` are\nnot supported.\n"},
  {"GetElementTypeMinValue", PyvtkQuerySelectionSource_GetElementTypeMinValue, METH_VARARGS,
   "V.GetElementTypeMinValue() -> int\nC++: virtual int GetElementTypeMinValue()\n\nSet/Get which types of elements are being selected. Accepted\nvalues are defined in `vtkDataObject::AttributeTypes`. Note,\n`vtkDataObject::FIELD` and `vtkDataObject::POINT_THEN_CELL` are\nnot supported.\n"},
  {"GetElementTypeMaxValue", PyvtkQuerySelectionSource_GetElementTypeMaxValue, METH_VARARGS,
   "V.GetElementTypeMaxValue() -> int\nC++: virtual int GetElementTypeMaxValue()\n\nSet/Get which types of elements are being selected. Accepted\nvalues are defined in `vtkDataObject::AttributeTypes`. Note,\n`vtkDataObject::FIELD` and `vtkDataObject::POINT_THEN_CELL` are\nnot supported.\n"},
  {"GetElementType", PyvtkQuerySelectionSource_GetElementType, METH_VARARGS,
   "V.GetElementType() -> int\nC++: virtual int GetElementType()\n\nSet/Get which types of elements are being selected. Accepted\nvalues are defined in `vtkDataObject::AttributeTypes`. Note,\n`vtkDataObject::FIELD` and `vtkDataObject::POINT_THEN_CELL` are\nnot supported.\n"},
  {"GetUserFriendlyText", PyvtkQuerySelectionSource_GetUserFriendlyText, METH_VARARGS,
   "V.GetUserFriendlyText() -> string\nC++: const char *GetUserFriendlyText()\n\nThis merely reconstructs the query as a user friendly text eg. \"IDs >=\n12\".\n"},
  {"SetInverse", PyvtkQuerySelectionSource_SetInverse, METH_VARARGS,
   "V.SetInverse(bool)\nC++: virtual void SetInverse(bool _arg)\n\nSet/get the invert selection flag.\n"},
  {"GetInverse", PyvtkQuerySelectionSource_GetInverse, METH_VARARGS,
   "V.GetInverse() -> bool\nC++: virtual bool GetInverse()\n\nSet/get the invert selection flag.\n"},
  {"SetNumberOfLayers", PyvtkQuerySelectionSource_SetNumberOfLayers, METH_VARARGS,
   "V.SetNumberOfLayers(int)\nC++: virtual void SetNumberOfLayers(int _arg)\n\nSpecify number of layers to extract connected to the selected\nelements.\n"},
  {"GetNumberOfLayersMinValue", PyvtkQuerySelectionSource_GetNumberOfLayersMinValue, METH_VARARGS,
   "V.GetNumberOfLayersMinValue() -> int\nC++: virtual int GetNumberOfLayersMinValue()\n\nSpecify number of layers to extract connected to the selected\nelements.\n"},
  {"GetNumberOfLayersMaxValue", PyvtkQuerySelectionSource_GetNumberOfLayersMaxValue, METH_VARARGS,
   "V.GetNumberOfLayersMaxValue() -> int\nC++: virtual int GetNumberOfLayersMaxValue()\n\nSpecify number of layers to extract connected to the selected\nelements.\n"},
  {"GetNumberOfLayers", PyvtkQuerySelectionSource_GetNumberOfLayers, METH_VARARGS,
   "V.GetNumberOfLayers() -> int\nC++: virtual int GetNumberOfLayers()\n\nSpecify number of layers to extract connected to the selected\nelements.\n"},
  {nullptr, nullptr, 0, nullptr}
};

#ifdef VTK_PYTHON_NEEDS_DEPRECATION_WARNING_SUPPRESSION
#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
#endif

static PyTypeObject PyvtkQuerySelectionSource_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  PYTHON_PACKAGE_SCOPE "vtkPVVTKExtensionsExtraction.vtkQuerySelectionSource", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
#if PY_VERSION_HEX >= 0x03080000
  0, // tp_vectorcall_offset
#else
  nullptr, // tp_print
#endif
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkQuerySelectionSource_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkQuerySelectionSource_StaticNew()
{
  return vtkQuerySelectionSource::New();
}

PyObject *PyvtkQuerySelectionSource_ClassNew()
{
  PyTypeObject *pytype = PyVTKClass_Add(
    &PyvtkQuerySelectionSource_Type, PyvtkQuerySelectionSource_Methods,
    "vtkQuerySelectionSource",
 &PyvtkQuerySelectionSource_StaticNew);

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#ifndef VTK_PY3K
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = vtkPythonUtil::FindClassTypeObject("vtkSelectionAlgorithm");

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkQuerySelectionSource(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkQuerySelectionSource_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkQuerySelectionSource", o) != 0)
  {
    Py_DECREF(o);
  }

}

