// python wrapper for vtkSteeringDataGenerator
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkSteeringDataGenerator.h"

#if defined(PYTHON_PACKAGE)
#define PYTHON_PACKAGE_SCOPE PYTHON_PACKAGE "."
#else
#define PYTHON_PACKAGE_SCOPE
#endif

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkSteeringDataGenerator(PyObject *dict); }
extern "C" { PyObject *PyvtkSteeringDataGenerator_ClassNew(); }


static const char *PyvtkSteeringDataGenerator_Doc =
  "vtkSteeringDataGenerator - source to generate dataset given field\narrays\n\n"
  "Superclass: vtkDataObjectAlgorithm\n\n"
  "vtkSteeringDataGenerator is simply a dataset generator that generates\n"
  "a single partition vtkMultiBlockDataSet with the 1st partition being\n"
  "non-empty dataset of the type specified using\n"
  "`vtkSteeringDataGenerator::SetPartitionType` with arrays added to the\n"
  "field type chosen using\n"
  "vtkSteeringDataGenerator::SetFieldAssociation`.\n\n"
  "If the PartitionType is a vtkPointSet subclass, then one can use\n"
  "**coords** as the field array name to add point coordinates when\n"
  "FieldAssociation is set to vtkDataObject::FIELD_ASSOCIATION_POINTS.\n\n"
  "A sample proxy definition that uses this source is as follows:\n\n"
  "{xml}\n\n\n"
  " <ProxyGroup name=\"sources\">\n"
  "    <!--\n"
  "====================================================================\n"
  "-->\n"
  "    <SourceProxy class=\"vtkSteeringDataGenerator\"\n"
  "name=\"TestSteeringDataGeneratorSource\">\n\n\n"
  "      <IntVectorProperty name=\"PartitionType\"\n"
  "                         command=\"SetPartitionType\"\n"
  "                         number_of_elements=\"1\"\n"
  "                         default_values=\"0\"\n"
  "                         panel_visibility=\"never\">\n"
  "        <!-- 0 == VTK_POLY_DATA -->\n"
  "      \n\n\n"
  "      <IntVectorProperty name=\"FieldAssociation\"\n"
  "                         command=\"SetFieldAssociation\"\n"
  "                         number_of_elements=\"1\"\n"
  "                         default_values=\"0\"\n"
  "                         panel_visibility=\"never\" />\n\n\n"
  "      <DoubleVectorProperty name=\"Center\"\n"
  "                            command=\"SetTuple3Double\"\n"
  "                            use_index=\"1\"\n"
  "                            clean_command=\"Clear\"\n"
  "                            initial_string=\"coords\"\n"
  "                            number_of_elements_per_command=\"3\"\n"
  "                            repeat_command=\"1\" />\n\n\n"
  "      <IdTypeVectorProperty name=\"Id\"\n"
  "                            command=\"SetTuple2IdType\"\n"
  "                            clean_command=\"Clear\"\n"
  "                            use_index=\"1\"\n"
  "                            initial_string=\"Id\"\n"
  "                            number_of_elements_per_command=\"2\"\n"
  "                            repeat_command=\"1\" />\n\n\n"
  "      <IntVectorProperty name=\"Type\"\n"
  "                         command=\"SetTuple1Int\"\n"
  "                         clean_command=\"Clear\"\n"
  "                         use_index=\"1\"\n"
  "                         initial_string=\"Type\"\n"
  "                         number_of_elements_per_command=\"1\"\n"
  "                         repeat_command=\"1\" />\n"
  "    \n"
  "   \n\n"
  "@section Caveats Caveats\n\n"
  "This filter should ideally generated `vtkPartitionedDataSet`.\n"
  "However, until `vtkPartitionedDataSet` is well supported, we are\n"
  "making it generate vtkMultiBlockDataSet.\n\n";


static PyObject *
PyvtkSteeringDataGenerator_IsTypeOf(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkSteeringDataGenerator::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSteeringDataGenerator *op = static_cast<vtkSteeringDataGenerator *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkSteeringDataGenerator::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_SafeDownCast(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkSteeringDataGenerator *tempr = vtkSteeringDataGenerator::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSteeringDataGenerator *op = static_cast<vtkSteeringDataGenerator *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkSteeringDataGenerator *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkSteeringDataGenerator::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(nullptr);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_GetNumberOfGenerationsFromBaseType(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetNumberOfGenerationsFromBaseType");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkSteeringDataGenerator::GetNumberOfGenerationsFromBaseType(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_GetNumberOfGenerationsFromBase(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGenerationsFromBase");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSteeringDataGenerator *op = static_cast<vtkSteeringDataGenerator *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfGenerationsFromBase(temp0) :
      op->vtkSteeringDataGenerator::GetNumberOfGenerationsFromBase(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_SetPartitionType(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetPartitionType");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSteeringDataGenerator *op = static_cast<vtkSteeringDataGenerator *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetPartitionType(temp0);
    }
    else
    {
      op->vtkSteeringDataGenerator::SetPartitionType(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_GetPartitionType(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetPartitionType");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSteeringDataGenerator *op = static_cast<vtkSteeringDataGenerator *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetPartitionType() :
      op->vtkSteeringDataGenerator::GetPartitionType());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_SetFieldAssociation(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetFieldAssociation");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSteeringDataGenerator *op = static_cast<vtkSteeringDataGenerator *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetFieldAssociation(temp0);
    }
    else
    {
      op->vtkSteeringDataGenerator::SetFieldAssociation(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_GetFieldAssociation(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetFieldAssociation");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSteeringDataGenerator *op = static_cast<vtkSteeringDataGenerator *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetFieldAssociation() :
      op->vtkSteeringDataGenerator::GetFieldAssociation());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_SetTuple1Double(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetTuple1Double");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSteeringDataGenerator *op = static_cast<vtkSteeringDataGenerator *>(vp);

  const char *temp0 = nullptr;
  int temp1;
  double temp2;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(3) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2))
  {
    if (ap.IsBound())
    {
      op->SetTuple1Double(temp0, temp1, temp2);
    }
    else
    {
      op->vtkSteeringDataGenerator::SetTuple1Double(temp0, temp1, temp2);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_SetTuple1Int(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetTuple1Int");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSteeringDataGenerator *op = static_cast<vtkSteeringDataGenerator *>(vp);

  const char *temp0 = nullptr;
  int temp1;
  int temp2;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(3) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2))
  {
    if (ap.IsBound())
    {
      op->SetTuple1Int(temp0, temp1, temp2);
    }
    else
    {
      op->vtkSteeringDataGenerator::SetTuple1Int(temp0, temp1, temp2);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_SetTuple1IdType(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetTuple1IdType");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSteeringDataGenerator *op = static_cast<vtkSteeringDataGenerator *>(vp);

  const char *temp0 = nullptr;
  int temp1;
  int temp2;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(3) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2))
  {
    if (ap.IsBound())
    {
      op->SetTuple1IdType(temp0, temp1, temp2);
    }
    else
    {
      op->vtkSteeringDataGenerator::SetTuple1IdType(temp0, temp1, temp2);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_SetTuple2Double(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetTuple2Double");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSteeringDataGenerator *op = static_cast<vtkSteeringDataGenerator *>(vp);

  const char *temp0 = nullptr;
  int temp1;
  double temp2;
  double temp3;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(4) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2) &&
      ap.GetValue(temp3))
  {
    if (ap.IsBound())
    {
      op->SetTuple2Double(temp0, temp1, temp2, temp3);
    }
    else
    {
      op->vtkSteeringDataGenerator::SetTuple2Double(temp0, temp1, temp2, temp3);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_SetTuple2Int(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetTuple2Int");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSteeringDataGenerator *op = static_cast<vtkSteeringDataGenerator *>(vp);

  const char *temp0 = nullptr;
  int temp1;
  int temp2;
  int temp3;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(4) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2) &&
      ap.GetValue(temp3))
  {
    if (ap.IsBound())
    {
      op->SetTuple2Int(temp0, temp1, temp2, temp3);
    }
    else
    {
      op->vtkSteeringDataGenerator::SetTuple2Int(temp0, temp1, temp2, temp3);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_SetTuple2IdType(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetTuple2IdType");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSteeringDataGenerator *op = static_cast<vtkSteeringDataGenerator *>(vp);

  const char *temp0 = nullptr;
  int temp1;
  int temp2;
  int temp3;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(4) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2) &&
      ap.GetValue(temp3))
  {
    if (ap.IsBound())
    {
      op->SetTuple2IdType(temp0, temp1, temp2, temp3);
    }
    else
    {
      op->vtkSteeringDataGenerator::SetTuple2IdType(temp0, temp1, temp2, temp3);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_SetTuple3Double(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetTuple3Double");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSteeringDataGenerator *op = static_cast<vtkSteeringDataGenerator *>(vp);

  const char *temp0 = nullptr;
  int temp1;
  double temp2;
  double temp3;
  double temp4;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(5) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2) &&
      ap.GetValue(temp3) &&
      ap.GetValue(temp4))
  {
    if (ap.IsBound())
    {
      op->SetTuple3Double(temp0, temp1, temp2, temp3, temp4);
    }
    else
    {
      op->vtkSteeringDataGenerator::SetTuple3Double(temp0, temp1, temp2, temp3, temp4);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_SetTuple3Int(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetTuple3Int");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSteeringDataGenerator *op = static_cast<vtkSteeringDataGenerator *>(vp);

  const char *temp0 = nullptr;
  int temp1;
  int temp2;
  int temp3;
  int temp4;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(5) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2) &&
      ap.GetValue(temp3) &&
      ap.GetValue(temp4))
  {
    if (ap.IsBound())
    {
      op->SetTuple3Int(temp0, temp1, temp2, temp3, temp4);
    }
    else
    {
      op->vtkSteeringDataGenerator::SetTuple3Int(temp0, temp1, temp2, temp3, temp4);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_SetTuple3IdType(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetTuple3IdType");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSteeringDataGenerator *op = static_cast<vtkSteeringDataGenerator *>(vp);

  const char *temp0 = nullptr;
  int temp1;
  int temp2;
  int temp3;
  int temp4;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(5) &&
      ap.GetValue(temp0) &&
      ap.GetValue(temp1) &&
      ap.GetValue(temp2) &&
      ap.GetValue(temp3) &&
      ap.GetValue(temp4))
  {
    if (ap.IsBound())
    {
      op->SetTuple3IdType(temp0, temp1, temp2, temp3, temp4);
    }
    else
    {
      op->vtkSteeringDataGenerator::SetTuple3IdType(temp0, temp1, temp2, temp3, temp4);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSteeringDataGenerator_Clear(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "Clear");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSteeringDataGenerator *op = static_cast<vtkSteeringDataGenerator *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->Clear(temp0);
    }
    else
    {
      op->vtkSteeringDataGenerator::Clear(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyMethodDef PyvtkSteeringDataGenerator_Methods[] = {
  {"IsTypeOf", PyvtkSteeringDataGenerator_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkSteeringDataGenerator_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkSteeringDataGenerator_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkSteeringDataGenerator\nC++: static vtkSteeringDataGenerator *SafeDownCast(\n    vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkSteeringDataGenerator_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkSteeringDataGenerator\nC++: vtkSteeringDataGenerator *NewInstance()\n\n"},
  {"GetNumberOfGenerationsFromBaseType", PyvtkSteeringDataGenerator_GetNumberOfGenerationsFromBaseType, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBaseType(string) -> int\nC++: static vtkIdType GetNumberOfGenerationsFromBaseType(\n    const char *type)\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"GetNumberOfGenerationsFromBase", PyvtkSteeringDataGenerator_GetNumberOfGenerationsFromBase, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBase(string) -> int\nC++: vtkIdType GetNumberOfGenerationsFromBase(const char *type)\n    override;\n\nGiven the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SetPartitionType", PyvtkSteeringDataGenerator_SetPartitionType, METH_VARARGS,
   "V.SetPartitionType(int)\nC++: virtual void SetPartitionType(int _arg)\n\nChoose the type for a parition in the output\nvtkMultiBlockDataSet. Accepted values are any non-composite\ndataset type know to vtkDataObjectTypes.\n"},
  {"GetPartitionType", PyvtkSteeringDataGenerator_GetPartitionType, METH_VARARGS,
   "V.GetPartitionType() -> int\nC++: virtual int GetPartitionType()\n\nChoose the type for a parition in the output\nvtkMultiBlockDataSet. Accepted values are any non-composite\ndataset type know to vtkDataObjectTypes.\n"},
  {"SetFieldAssociation", PyvtkSteeringDataGenerator_SetFieldAssociation, METH_VARARGS,
   "V.SetFieldAssociation(int)\nC++: virtual void SetFieldAssociation(int _arg)\n\nIndicate the field association to which the specified data arrays\nare added. The FieldAssociation must make sense for the chosen\nPartitionType i.e. setting FieldAssociation to\nvtkDataObjectTypes::FIELD_ASSOCIATION_ROWS for a PartitionType of\nVTK_POLY_DATA is invalid.\n"},
  {"GetFieldAssociation", PyvtkSteeringDataGenerator_GetFieldAssociation, METH_VARARGS,
   "V.GetFieldAssociation() -> int\nC++: virtual int GetFieldAssociation()\n\nIndicate the field association to which the specified data arrays\nare added. The FieldAssociation must make sense for the chosen\nPartitionType i.e. setting FieldAssociation to\nvtkDataObjectTypes::FIELD_ASSOCIATION_ROWS for a PartitionType of\nVTK_POLY_DATA is invalid.\n"},
  {"SetTuple1Double", PyvtkSteeringDataGenerator_SetTuple1Double, METH_VARARGS,
   "V.SetTuple1Double(string, int, float)\nC++: void SetTuple1Double(const char *arrayname, vtkIdType index,\n    double val)\n\nMethods to add individual tuples to the data arrays. The number\nof components and type of the array depends on the API overload\nused. The array is idenfied using arrayname. Array names are\nassumed unique. Changing the type or components of any array\nwithout calling `Clear` first is not supported. The array will be\nresized to contain the tuple indicated.\n"},
  {"SetTuple1Int", PyvtkSteeringDataGenerator_SetTuple1Int, METH_VARARGS,
   "V.SetTuple1Int(string, int, int)\nC++: void SetTuple1Int(const char *arrayname, vtkIdType index,\n    int val)\n\nMethods to add individual tuples to the data arrays. The number\nof components and type of the array depends on the API overload\nused. The array is idenfied using arrayname. Array names are\nassumed unique. Changing the type or components of any array\nwithout calling `Clear` first is not supported. The array will be\nresized to contain the tuple indicated.\n"},
  {"SetTuple1IdType", PyvtkSteeringDataGenerator_SetTuple1IdType, METH_VARARGS,
   "V.SetTuple1IdType(string, int, int)\nC++: void SetTuple1IdType(const char *arrayname, vtkIdType index,\n    vtkIdType val)\n\nMethods to add individual tuples to the data arrays. The number\nof components and type of the array depends on the API overload\nused. The array is idenfied using arrayname. Array names are\nassumed unique. Changing the type or components of any array\nwithout calling `Clear` first is not supported. The array will be\nresized to contain the tuple indicated.\n"},
  {"SetTuple2Double", PyvtkSteeringDataGenerator_SetTuple2Double, METH_VARARGS,
   "V.SetTuple2Double(string, int, float, float)\nC++: void SetTuple2Double(const char *arrayname, vtkIdType index,\n    double val0, double val1)\n\nMethods to add individual tuples to the data arrays. The number\nof components and type of the array depends on the API overload\nused. The array is idenfied using arrayname. Array names are\nassumed unique. Changing the type or components of any array\nwithout calling `Clear` first is not supported. The array will be\nresized to contain the tuple indicated.\n"},
  {"SetTuple2Int", PyvtkSteeringDataGenerator_SetTuple2Int, METH_VARARGS,
   "V.SetTuple2Int(string, int, int, int)\nC++: void SetTuple2Int(const char *arrayname, vtkIdType index,\n    int val0, int val1)\n\nMethods to add individual tuples to the data arrays. The number\nof components and type of the array depends on the API overload\nused. The array is idenfied using arrayname. Array names are\nassumed unique. Changing the type or components of any array\nwithout calling `Clear` first is not supported. The array will be\nresized to contain the tuple indicated.\n"},
  {"SetTuple2IdType", PyvtkSteeringDataGenerator_SetTuple2IdType, METH_VARARGS,
   "V.SetTuple2IdType(string, int, int, int)\nC++: void SetTuple2IdType(const char *arrayname, vtkIdType index,\n    vtkIdType val0, vtkIdType val1)\n\nMethods to add individual tuples to the data arrays. The number\nof components and type of the array depends on the API overload\nused. The array is idenfied using arrayname. Array names are\nassumed unique. Changing the type or components of any array\nwithout calling `Clear` first is not supported. The array will be\nresized to contain the tuple indicated.\n"},
  {"SetTuple3Double", PyvtkSteeringDataGenerator_SetTuple3Double, METH_VARARGS,
   "V.SetTuple3Double(string, int, float, float, float)\nC++: void SetTuple3Double(const char *arrayname, vtkIdType index,\n    double val0, double val1, double val2)\n\nMethods to add individual tuples to the data arrays. The number\nof components and type of the array depends on the API overload\nused. The array is idenfied using arrayname. Array names are\nassumed unique. Changing the type or components of any array\nwithout calling `Clear` first is not supported. The array will be\nresized to contain the tuple indicated.\n"},
  {"SetTuple3Int", PyvtkSteeringDataGenerator_SetTuple3Int, METH_VARARGS,
   "V.SetTuple3Int(string, int, int, int, int)\nC++: void SetTuple3Int(const char *arrayname, vtkIdType index,\n    int val0, int val1, int val2)\n\nMethods to add individual tuples to the data arrays. The number\nof components and type of the array depends on the API overload\nused. The array is idenfied using arrayname. Array names are\nassumed unique. Changing the type or components of any array\nwithout calling `Clear` first is not supported. The array will be\nresized to contain the tuple indicated.\n"},
  {"SetTuple3IdType", PyvtkSteeringDataGenerator_SetTuple3IdType, METH_VARARGS,
   "V.SetTuple3IdType(string, int, int, int, int)\nC++: void SetTuple3IdType(const char *arrayname, vtkIdType index,\n    vtkIdType val0, vtkIdType val1, vtkIdType val3)\n\nMethods to add individual tuples to the data arrays. The number\nof components and type of the array depends on the API overload\nused. The array is idenfied using arrayname. Array names are\nassumed unique. Changing the type or components of any array\nwithout calling `Clear` first is not supported. The array will be\nresized to contain the tuple indicated.\n"},
  {"Clear", PyvtkSteeringDataGenerator_Clear, METH_VARARGS,
   "V.Clear(string)\nC++: void Clear(const char *arrayname)\n\nRemove the array identified by the arrayname, if any.\n"},
  {nullptr, nullptr, 0, nullptr}
};

#ifdef VTK_PYTHON_NEEDS_DEPRECATION_WARNING_SUPPRESSION
#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
#endif

static PyTypeObject PyvtkSteeringDataGenerator_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  PYTHON_PACKAGE_SCOPE "vtkRemotingLive.vtkSteeringDataGenerator", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
#if PY_VERSION_HEX >= 0x03080000
  0, // tp_vectorcall_offset
#else
  nullptr, // tp_print
#endif
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkSteeringDataGenerator_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkSteeringDataGenerator_StaticNew()
{
  return vtkSteeringDataGenerator::New();
}

PyObject *PyvtkSteeringDataGenerator_ClassNew()
{
  PyTypeObject *pytype = PyVTKClass_Add(
    &PyvtkSteeringDataGenerator_Type, PyvtkSteeringDataGenerator_Methods,
    "vtkSteeringDataGenerator",
 &PyvtkSteeringDataGenerator_StaticNew);

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#ifndef VTK_PY3K
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = vtkPythonUtil::FindClassTypeObject("vtkDataObjectAlgorithm");

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkSteeringDataGenerator(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkSteeringDataGenerator_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkSteeringDataGenerator", o) != 0)
  {
    Py_DECREF(o);
  }

}

