// python wrapper for vtkRemoteWriterHelper
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkRemoteWriterHelper.h"

#if defined(PYTHON_PACKAGE)
#define PYTHON_PACKAGE_SCOPE PYTHON_PACKAGE "."
#else
#define PYTHON_PACKAGE_SCOPE
#endif

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkRemoteWriterHelper(PyObject *dict); }
extern "C" { PyObject *PyvtkRemoteWriterHelper_ClassNew(); }


static const char *PyvtkRemoteWriterHelper_Doc =
  "vtkRemoteWriterHelper - Helper to write data on client or\ndata-server-root.\n\n"
  "Superclass: vtkDataObjectAlgorithm\n\n"
  "vtkRemoteWriterHelper is designed to be used to write data that is\n"
  "being generated on the client-side either directly on the client or\n"
  "on the data-server root node. This is useful for saving data such as\n"
  "screenshots, state files, etc. that are generated on the client-side\n"
  "but sometimes needs to be saved remotely on the data-server root node\n"
  "instead.\n\n"
  "To use, simply create the (\"misc\", \"NetworkImageWriter\") proxy. The\n"
  "proxy creates this class on client and data-server. Next, using the\n"
  "client-side object, pass the input data to the client-instance and\n"
  "then set `OutputDestination` property as needed. The actual writer to\n"
  "use must be set using the \"Writer\" property. Now, when you call\n"
  "UpdatePipeline, the vtkRemoteWriterHelper will transfer data if\n"
  "needed and then invoke the writer's Write method on the target\n"
  "process.\n\n";


static PyObject *
PyvtkRemoteWriterHelper_IsTypeOf(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkRemoteWriterHelper::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkRemoteWriterHelper_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkRemoteWriterHelper *op = static_cast<vtkRemoteWriterHelper *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkRemoteWriterHelper::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkRemoteWriterHelper_SafeDownCast(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkRemoteWriterHelper *tempr = vtkRemoteWriterHelper::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkRemoteWriterHelper_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkRemoteWriterHelper *op = static_cast<vtkRemoteWriterHelper *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkRemoteWriterHelper *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkRemoteWriterHelper::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(nullptr);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkRemoteWriterHelper_GetNumberOfGenerationsFromBaseType(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetNumberOfGenerationsFromBaseType");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkRemoteWriterHelper::GetNumberOfGenerationsFromBaseType(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkRemoteWriterHelper_GetNumberOfGenerationsFromBase(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGenerationsFromBase");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkRemoteWriterHelper *op = static_cast<vtkRemoteWriterHelper *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfGenerationsFromBase(temp0) :
      op->vtkRemoteWriterHelper::GetNumberOfGenerationsFromBase(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkRemoteWriterHelper_SetWriter(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetWriter");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkRemoteWriterHelper *op = static_cast<vtkRemoteWriterHelper *>(vp);

  vtkAlgorithm *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkAlgorithm"))
  {
    if (ap.IsBound())
    {
      op->SetWriter(temp0);
    }
    else
    {
      op->vtkRemoteWriterHelper::SetWriter(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkRemoteWriterHelper_GetWriter(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetWriter");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkRemoteWriterHelper *op = static_cast<vtkRemoteWriterHelper *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkAlgorithm *tempr = (ap.IsBound() ?
      op->GetWriter() :
      op->vtkRemoteWriterHelper::GetWriter());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkRemoteWriterHelper_SetOutputDestination(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetOutputDestination");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkRemoteWriterHelper *op = static_cast<vtkRemoteWriterHelper *>(vp);

  unsigned int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetOutputDestination(temp0);
    }
    else
    {
      op->vtkRemoteWriterHelper::SetOutputDestination(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkRemoteWriterHelper_GetOutputDestination(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetOutputDestination");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkRemoteWriterHelper *op = static_cast<vtkRemoteWriterHelper *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    unsigned int tempr = (ap.IsBound() ?
      op->GetOutputDestination() :
      op->vtkRemoteWriterHelper::GetOutputDestination());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkRemoteWriterHelper_SetInterpreter(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetInterpreter");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkRemoteWriterHelper *op = static_cast<vtkRemoteWriterHelper *>(vp);

  vtkClientServerInterpreter *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkClientServerInterpreter"))
  {
    if (ap.IsBound())
    {
      op->SetInterpreter(temp0);
    }
    else
    {
      op->vtkRemoteWriterHelper::SetInterpreter(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkRemoteWriterHelper_GetInterpreter(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetInterpreter");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkRemoteWriterHelper *op = static_cast<vtkRemoteWriterHelper *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkClientServerInterpreter *tempr = (ap.IsBound() ?
      op->GetInterpreter() :
      op->vtkRemoteWriterHelper::GetInterpreter());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}

static PyMethodDef PyvtkRemoteWriterHelper_Methods[] = {
  {"IsTypeOf", PyvtkRemoteWriterHelper_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkRemoteWriterHelper_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkRemoteWriterHelper_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkRemoteWriterHelper\nC++: static vtkRemoteWriterHelper *SafeDownCast(vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkRemoteWriterHelper_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkRemoteWriterHelper\nC++: vtkRemoteWriterHelper *NewInstance()\n\n"},
  {"GetNumberOfGenerationsFromBaseType", PyvtkRemoteWriterHelper_GetNumberOfGenerationsFromBaseType, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBaseType(string) -> int\nC++: static vtkIdType GetNumberOfGenerationsFromBaseType(\n    const char *type)\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"GetNumberOfGenerationsFromBase", PyvtkRemoteWriterHelper_GetNumberOfGenerationsFromBase, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBase(string) -> int\nC++: vtkIdType GetNumberOfGenerationsFromBase(const char *type)\n    override;\n\nGiven the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SetWriter", PyvtkRemoteWriterHelper_SetWriter, METH_VARARGS,
   "V.SetWriter(vtkAlgorithm)\nC++: void SetWriter(vtkAlgorithm *writer)\n\nGet/Set the Image writer\n"},
  {"GetWriter", PyvtkRemoteWriterHelper_GetWriter, METH_VARARGS,
   "V.GetWriter() -> vtkAlgorithm\nC++: virtual vtkAlgorithm *GetWriter()\n\nGet/Set the Image writer\n"},
  {"SetOutputDestination", PyvtkRemoteWriterHelper_SetOutputDestination, METH_VARARGS,
   "V.SetOutputDestination(int)\nC++: virtual void SetOutputDestination(vtkTypeUInt32 _arg)\n\nGet/Set the process on which the data must be written. Currently\nsupported values are vtkPVSession::CLIENT and\nvtkPVSession::DATA_SERVER_ROOT (or vtkPVSession::DATA_SERVER).\nvtkPVSession::DATA_SERVER and vtkPVSession::DATA_SERVER_ROOT are\ntreated identically since the data is only written on the root\nnode.\n"},
  {"GetOutputDestination", PyvtkRemoteWriterHelper_GetOutputDestination, METH_VARARGS,
   "V.GetOutputDestination() -> int\nC++: virtual vtkTypeUInt32 GetOutputDestination()\n\nGet/Set the process on which the data must be written. Currently\nsupported values are vtkPVSession::CLIENT and\nvtkPVSession::DATA_SERVER_ROOT (or vtkPVSession::DATA_SERVER).\nvtkPVSession::DATA_SERVER and vtkPVSession::DATA_SERVER_ROOT are\ntreated identically since the data is only written on the root\nnode.\n"},
  {"SetInterpreter", PyvtkRemoteWriterHelper_SetInterpreter, METH_VARARGS,
   "V.SetInterpreter(vtkClientServerInterpreter)\nC++: void SetInterpreter(vtkClientServerInterpreter *interp)\n\nSet the interpreter to use to call methods on the writer.\nInitialized to\n`vtkClientServerInterpreterInitializer::GetGlobalInterpreter()`\nin the constructor.\n"},
  {"GetInterpreter", PyvtkRemoteWriterHelper_GetInterpreter, METH_VARARGS,
   "V.GetInterpreter() -> vtkClientServerInterpreter\nC++: virtual vtkClientServerInterpreter *GetInterpreter()\n\nSet the interpreter to use to call methods on the writer.\nInitialized to\n`vtkClientServerInterpreterInitializer::GetGlobalInterpreter()`\nin the constructor.\n"},
  {nullptr, nullptr, 0, nullptr}
};

#ifdef VTK_PYTHON_NEEDS_DEPRECATION_WARNING_SUPPRESSION
#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
#endif

static PyTypeObject PyvtkRemoteWriterHelper_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  PYTHON_PACKAGE_SCOPE "vtkRemotingServerManager.vtkRemoteWriterHelper", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
#if PY_VERSION_HEX >= 0x03080000
  0, // tp_vectorcall_offset
#else
  nullptr, // tp_print
#endif
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkRemoteWriterHelper_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkRemoteWriterHelper_StaticNew()
{
  return vtkRemoteWriterHelper::New();
}

PyObject *PyvtkRemoteWriterHelper_ClassNew()
{
  PyTypeObject *pytype = PyVTKClass_Add(
    &PyvtkRemoteWriterHelper_Type, PyvtkRemoteWriterHelper_Methods,
    "vtkRemoteWriterHelper",
 &PyvtkRemoteWriterHelper_StaticNew);

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#ifndef VTK_PY3K
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = vtkPythonUtil::FindClassTypeObject("vtkDataObjectAlgorithm");

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkRemoteWriterHelper(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkRemoteWriterHelper_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkRemoteWriterHelper", o) != 0)
  {
    Py_DECREF(o);
  }

}

