// python wrapper for vtkSMExtractsController
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkSMExtractsController.h"

#if defined(PYTHON_PACKAGE)
#define PYTHON_PACKAGE_SCOPE PYTHON_PACKAGE "."
#else
#define PYTHON_PACKAGE_SCOPE
#endif

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkSMExtractsController(PyObject *dict); }
extern "C" { PyObject *PyvtkSMExtractsController_ClassNew(); }


static const char *PyvtkSMExtractsController_Doc =
  "vtkSMExtractsController - controller for extract generation\n\n"
  "Superclass: vtkObject\n\n"
  "vtkSMExtractsController is a controllers that provides API to handle\n"
  "various aspects of extractors and extract generation mechanisms\n"
  "supported by ParaView.\n\n"
  "It provides API to query, create extractors of known types. It also\n"
  "provides API to generate extracts using the defined extractors.\n\n"
  "@section GeneratingExtractsSummary Summary of generated extracts\n\n"
  "vtkSMExtractsController generates a summary table for all extracts\n"
  "generated. Each row in this summary table corresponds to an extract\n"
  "generated. Each column provides information about that extract.\n"
  "Filename for the extract is stored in a column named `FILE_[type]`\n"
  "where `[type]` is replaced by the extension of the file. Other\n"
  "columns are used to stored named values that characterize the\n"
  "extract.\n\n"
  "Currently, this summary table is used to generated a Cinema\n"
  "specification which can be used to explore the generated extracts\n"
  "using Cinema tools (https://cinemascience.github.io/).\n\n";


static PyObject *
PyvtkSMExtractsController_IsTypeOf(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkSMExtractsController::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkSMExtractsController::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_SafeDownCast(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkSMExtractsController *tempr = vtkSMExtractsController::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkSMExtractsController *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkSMExtractsController::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(nullptr);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_GetNumberOfGenerationsFromBaseType(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "GetNumberOfGenerationsFromBaseType");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkSMExtractsController::GetNumberOfGenerationsFromBaseType(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_GetNumberOfGenerationsFromBase(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfGenerationsFromBase");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfGenerationsFromBase(temp0) :
      op->vtkSMExtractsController::GetNumberOfGenerationsFromBase(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_SetTimeStep(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetTimeStep");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetTimeStep(temp0);
    }
    else
    {
      op->vtkSMExtractsController::SetTimeStep(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_GetTimeStepMinValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetTimeStepMinValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetTimeStepMinValue() :
      op->vtkSMExtractsController::GetTimeStepMinValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_GetTimeStepMaxValue(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetTimeStepMaxValue");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetTimeStepMaxValue() :
      op->vtkSMExtractsController::GetTimeStepMaxValue());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_GetTimeStep(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetTimeStep");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetTimeStep() :
      op->vtkSMExtractsController::GetTimeStep());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_SetTime(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetTime");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  double temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetTime(temp0);
    }
    else
    {
      op->vtkSMExtractsController::SetTime(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_GetTime(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetTime");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    double tempr = (ap.IsBound() ?
      op->GetTime() :
      op->vtkSMExtractsController::GetTime());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_SetExtractsOutputDirectory(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetExtractsOutputDirectory");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetExtractsOutputDirectory(temp0);
    }
    else
    {
      op->vtkSMExtractsController::SetExtractsOutputDirectory(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_GetExtractsOutputDirectory(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetExtractsOutputDirectory");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    char *tempr = (ap.IsBound() ?
      op->GetExtractsOutputDirectory() :
      op->vtkSMExtractsController::GetExtractsOutputDirectory());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_GetRealExtractsOutputDirectory(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetRealExtractsOutputDirectory");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    const char *tempr = (ap.IsBound() ?
      op->GetRealExtractsOutputDirectory() :
      op->vtkSMExtractsController::GetRealExtractsOutputDirectory());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_Extract_s1(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "Extract");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  vtkSMProxy *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkSMProxy"))
  {
    bool tempr = (ap.IsBound() ?
      op->Extract(temp0) :
      op->vtkSMExtractsController::Extract(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}

static PyObject *
PyvtkSMExtractsController_Extract_s2(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "Extract");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  vtkSMSessionProxyManager *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkSMSessionProxyManager"))
  {
    bool tempr = (ap.IsBound() ?
      op->Extract(temp0) :
      op->vtkSMExtractsController::Extract(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}

static PyObject *
PyvtkSMExtractsController_Extract_s3(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "Extract");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->Extract() :
      op->vtkSMExtractsController::Extract());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}

static PyObject *
PyvtkSMExtractsController_Extract_s4(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "Extract");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  vtkCollection *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkCollection"))
  {
    bool tempr = (ap.IsBound() ?
      op->Extract(temp0) :
      op->vtkSMExtractsController::Extract(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}

static PyMethodDef PyvtkSMExtractsController_Extract_Methods[] = {
  {nullptr, PyvtkSMExtractsController_Extract_s1, METH_VARARGS,
   "@V *vtkSMProxy"},
  {nullptr, PyvtkSMExtractsController_Extract_s2, METH_VARARGS,
   "@V *vtkSMSessionProxyManager"},
  {nullptr, PyvtkSMExtractsController_Extract_s4, METH_VARARGS,
   "@V *vtkCollection"},
  {nullptr, nullptr, 0, nullptr}
};

static PyObject *
PyvtkSMExtractsController_Extract(PyObject *self, PyObject *args)
{
  PyMethodDef *methods = PyvtkSMExtractsController_Extract_Methods;
  int nargs = vtkPythonArgs::GetArgCount(self, args);

  switch(nargs)
  {
    case 0:
      return PyvtkSMExtractsController_Extract_s3(self, args);
    case 1:
      return vtkPythonOverload::CallMethod(methods, self, args);
  }

  vtkPythonArgs::ArgCountError(nargs, "Extract");
  return nullptr;
}


static PyObject *
PyvtkSMExtractsController_IsAnyTriggerActivated_s1(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsAnyTriggerActivated");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  vtkSMSessionProxyManager *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkSMSessionProxyManager"))
  {
    bool tempr = (ap.IsBound() ?
      op->IsAnyTriggerActivated(temp0) :
      op->vtkSMExtractsController::IsAnyTriggerActivated(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}

static PyObject *
PyvtkSMExtractsController_IsAnyTriggerActivated_s2(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsAnyTriggerActivated");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->IsAnyTriggerActivated() :
      op->vtkSMExtractsController::IsAnyTriggerActivated());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}

static PyObject *
PyvtkSMExtractsController_IsAnyTriggerActivated_s3(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsAnyTriggerActivated");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  vtkCollection *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkCollection"))
  {
    bool tempr = (ap.IsBound() ?
      op->IsAnyTriggerActivated(temp0) :
      op->vtkSMExtractsController::IsAnyTriggerActivated(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}

static PyMethodDef PyvtkSMExtractsController_IsAnyTriggerActivated_Methods[] = {
  {nullptr, PyvtkSMExtractsController_IsAnyTriggerActivated_s1, METH_VARARGS,
   "@V *vtkSMSessionProxyManager"},
  {nullptr, PyvtkSMExtractsController_IsAnyTriggerActivated_s3, METH_VARARGS,
   "@V *vtkCollection"},
  {nullptr, nullptr, 0, nullptr}
};

static PyObject *
PyvtkSMExtractsController_IsAnyTriggerActivated(PyObject *self, PyObject *args)
{
  PyMethodDef *methods = PyvtkSMExtractsController_IsAnyTriggerActivated_Methods;
  int nargs = vtkPythonArgs::GetArgCount(self, args);

  switch(nargs)
  {
    case 0:
      return PyvtkSMExtractsController_IsAnyTriggerActivated_s2(self, args);
    case 1:
      return vtkPythonOverload::CallMethod(methods, self, args);
  }

  vtkPythonArgs::ArgCountError(nargs, "IsAnyTriggerActivated");
  return nullptr;
}


static PyObject *
PyvtkSMExtractsController_IsTriggerActivated(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsTriggerActivated");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  vtkSMProxy *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkSMProxy"))
  {
    bool tempr = (ap.IsBound() ?
      op->IsTriggerActivated(temp0) :
      op->vtkSMExtractsController::IsTriggerActivated(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_CanExtract(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "CanExtract");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  vtkSMProxy *temp0 = nullptr;
  vtkSMProxy *temp1 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetVTKObject(temp0, "vtkSMProxy") &&
      ap.GetVTKObject(temp1, "vtkSMProxy"))
  {
    bool tempr = (ap.IsBound() ?
      op->CanExtract(temp0, temp1) :
      op->vtkSMExtractsController::CanExtract(temp0, temp1));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_CreateExtractor(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "CreateExtractor");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  vtkSMProxy *temp0 = nullptr;
  const char *temp1 = nullptr;
  const char *temp2 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2, 3) &&
      ap.GetVTKObject(temp0, "vtkSMProxy") &&
      ap.GetValue(temp1) &&
      (ap.NoArgsLeft() || ap.GetValue(temp2)))
  {
    vtkSMProxy *tempr = (ap.IsBound() ?
      op->CreateExtractor(temp0, temp1, temp2) :
      op->vtkSMExtractsController::CreateExtractor(temp0, temp1, temp2));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_IsExtractor(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "IsExtractor");

  vtkSMProxy *temp0 = nullptr;
  vtkSMProxy *temp1 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(2) &&
      ap.GetVTKObject(temp0, "vtkSMProxy") &&
      ap.GetVTKObject(temp1, "vtkSMProxy"))
  {
    bool tempr = vtkSMExtractsController::IsExtractor(temp0, temp1);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_GetInputForExtractor(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetInputForExtractor");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  vtkSMProxy *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkSMProxy"))
  {
    vtkSMProxy *tempr = (ap.IsBound() ?
      op->GetInputForExtractor(temp0) :
      op->vtkSMExtractsController::GetInputForExtractor(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_GetSummaryTable(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetSummaryTable");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkTable *tempr = (ap.IsBound() ?
      op->GetSummaryTable() :
      op->vtkSMExtractsController::GetSummaryTable());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_ResetSummaryTable(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ResetSummaryTable");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ResetSummaryTable();
    }
    else
    {
      op->vtkSMExtractsController::ResetSummaryTable();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_SaveSummaryTable(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SaveSummaryTable");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkSMExtractsController *op = static_cast<vtkSMExtractsController *>(vp);

  std::string temp0;
  vtkSMSessionProxyManager *temp1 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetVTKObject(temp1, "vtkSMSessionProxyManager"))
  {
    bool tempr = (ap.IsBound() ?
      op->SaveSummaryTable(temp0, temp1) :
      op->vtkSMExtractsController::SaveSummaryTable(temp0, temp1));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_IsExtractorEnabled(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "IsExtractorEnabled");

  vtkSMProxy *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkSMProxy"))
  {
    bool tempr = vtkSMExtractsController::IsExtractorEnabled(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkSMExtractsController_SetExtractorEnabled(PyObject * /*unused*/, PyObject *args)
{
  vtkPythonArgs ap(args, "SetExtractorEnabled");

  vtkSMProxy *temp0 = nullptr;
  bool temp1 = false;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(2) &&
      ap.GetVTKObject(temp0, "vtkSMProxy") &&
      ap.GetValue(temp1))
  {
    vtkSMExtractsController::SetExtractorEnabled(temp0, temp1);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyMethodDef PyvtkSMExtractsController_Methods[] = {
  {"IsTypeOf", PyvtkSMExtractsController_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkSMExtractsController_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkSMExtractsController_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkSMExtractsController\nC++: static vtkSMExtractsController *SafeDownCast(\n    vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkSMExtractsController_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkSMExtractsController\nC++: vtkSMExtractsController *NewInstance()\n\n"},
  {"GetNumberOfGenerationsFromBaseType", PyvtkSMExtractsController_GetNumberOfGenerationsFromBaseType, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBaseType(string) -> int\nC++: static vtkIdType GetNumberOfGenerationsFromBaseType(\n    const char *type)\n\nGiven a the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"GetNumberOfGenerationsFromBase", PyvtkSMExtractsController_GetNumberOfGenerationsFromBase, METH_VARARGS,
   "V.GetNumberOfGenerationsFromBase(string) -> int\nC++: vtkIdType GetNumberOfGenerationsFromBase(const char *type)\n    override;\n\nGiven the name of a base class of this class type, return the\ndistance of inheritance between this class type and the named\nclass (how many generations of inheritance are there between this\nclass and the named class). If the named class is not in this\nclass's inheritance tree, return a negative value. Valid\nresponses will always be nonnegative. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SetTimeStep", PyvtkSMExtractsController_SetTimeStep, METH_VARARGS,
   "V.SetTimeStep(int)\nC++: virtual void SetTimeStep(int _arg)\n\nInformation about current time/timestep. This must be set\ncorrectly before using `Extract` to generate extracts.\n"},
  {"GetTimeStepMinValue", PyvtkSMExtractsController_GetTimeStepMinValue, METH_VARARGS,
   "V.GetTimeStepMinValue() -> int\nC++: virtual int GetTimeStepMinValue()\n\nInformation about current time/timestep. This must be set\ncorrectly before using `Extract` to generate extracts.\n"},
  {"GetTimeStepMaxValue", PyvtkSMExtractsController_GetTimeStepMaxValue, METH_VARARGS,
   "V.GetTimeStepMaxValue() -> int\nC++: virtual int GetTimeStepMaxValue()\n\nInformation about current time/timestep. This must be set\ncorrectly before using `Extract` to generate extracts.\n"},
  {"GetTimeStep", PyvtkSMExtractsController_GetTimeStep, METH_VARARGS,
   "V.GetTimeStep() -> int\nC++: virtual int GetTimeStep()\n\nInformation about current time/timestep. This must be set\ncorrectly before using `Extract` to generate extracts.\n"},
  {"SetTime", PyvtkSMExtractsController_SetTime, METH_VARARGS,
   "V.SetTime(float)\nC++: virtual void SetTime(double _arg)\n\nInformation about current time/timestep. This must be set\ncorrectly before using `Extract` to generate extracts.\n"},
  {"GetTime", PyvtkSMExtractsController_GetTime, METH_VARARGS,
   "V.GetTime() -> float\nC++: virtual double GetTime()\n\nInformation about current time/timestep. This must be set\ncorrectly before using `Extract` to generate extracts.\n"},
  {"SetExtractsOutputDirectory", PyvtkSMExtractsController_SetExtractsOutputDirectory, METH_VARARGS,
   "V.SetExtractsOutputDirectory(string)\nC++: virtual void SetExtractsOutputDirectory(const char *_arg)\n\nGet/Set the root directory to use for writing extracts. This must\nbe set correctly before using `Extract` to generate extracts.\n\note This can be overridden at runtime using environment variable\n`PARAVIEW_OVERRIDE_EXTRACTS_OUTPUT_DIRECTORY`. If set, the value\nspecified here ignored and the environment variable is used\ninstead.\n"},
  {"GetExtractsOutputDirectory", PyvtkSMExtractsController_GetExtractsOutputDirectory, METH_VARARGS,
   "V.GetExtractsOutputDirectory() -> string\nC++: virtual char *GetExtractsOutputDirectory()\n\nGet/Set the root directory to use for writing extracts. This must\nbe set correctly before using `Extract` to generate extracts.\n\note This can be overridden at runtime using environment variable\n`PARAVIEW_OVERRIDE_EXTRACTS_OUTPUT_DIRECTORY`. If set, the value\nspecified here ignored and the environment variable is used\ninstead.\n"},
  {"GetRealExtractsOutputDirectory", PyvtkSMExtractsController_GetRealExtractsOutputDirectory, METH_VARARGS,
   "V.GetRealExtractsOutputDirectory() -> string\nC++: const char *GetRealExtractsOutputDirectory()\n\nReturns the extract output directory to use. If\n`PARAVIEW_OVERRIDE_EXTRACTS_OUTPUT_DIRECTORY` is not set, this\nwill be same as `GetExtractsOutputDirectory` else this will be\nthe value of the `PARAVIEW_OVERRIDE_EXTRACTS_OUTPUT_DIRECTORY`\nenvironment variable.\n"},
  {"Extract", PyvtkSMExtractsController_Extract, METH_VARARGS,
   "V.Extract(vtkSMProxy) -> bool\nC++: bool Extract(vtkSMProxy *extractor)\nV.Extract(vtkSMSessionProxyManager) -> bool\nC++: bool Extract(vtkSMSessionProxyManager *pxm)\nV.Extract() -> bool\nC++: bool Extract()\nV.Extract(vtkCollection) -> bool\nC++: bool Extract(vtkCollection *collection)\n\nGenerate the extract for the current state. Returns true if\nextract was generated, false if skipped or failed.\n\nThis overload generates extract from the specific extractor.\n"},
  {"IsAnyTriggerActivated", PyvtkSMExtractsController_IsAnyTriggerActivated, METH_VARARGS,
   "V.IsAnyTriggerActivated(vtkSMSessionProxyManager) -> bool\nC++: bool IsAnyTriggerActivated(vtkSMSessionProxyManager *pxm)\nV.IsAnyTriggerActivated() -> bool\nC++: bool IsAnyTriggerActivated()\nV.IsAnyTriggerActivated(vtkCollection) -> bool\nC++: bool IsAnyTriggerActivated(vtkCollection *collection)\n\nCheck if any of the extractors registered with the chosen\nproxy-manager (or active proxy-manager, is none specified) has\ntheir trigger activated given the current state of the\napplication and the values for Time and TimeStep set on the\ncontroller.\n"},
  {"IsTriggerActivated", PyvtkSMExtractsController_IsTriggerActivated, METH_VARARGS,
   "V.IsTriggerActivated(vtkSMProxy) -> bool\nC++: bool IsTriggerActivated(vtkSMProxy *extractor)\n\nSame as `IsAnyTriggerActivated` except only check the selected\nextractor's trigger definition.\n"},
  {"CanExtract", PyvtkSMExtractsController_CanExtract, METH_VARARGS,
   "V.CanExtract(vtkSMProxy, vtkSMProxy) -> bool\nC++: bool CanExtract(vtkSMProxy *extractor, vtkSMProxy *input)\n\n"},
  {"CreateExtractor", PyvtkSMExtractsController_CreateExtractor, METH_VARARGS,
   "V.CreateExtractor(vtkSMProxy, string, string) -> vtkSMProxy\nC++: vtkSMProxy *CreateExtractor(vtkSMProxy *proxy,\n    const char *xmlname, const char *registrationName=nullptr)\n\nCreates, initializes and registers a new extractor of the chosen\ntype.\n"},
  {"IsExtractor", PyvtkSMExtractsController_IsExtractor, METH_VARARGS,
   "V.IsExtractor(vtkSMProxy, vtkSMProxy) -> bool\nC++: static bool IsExtractor(vtkSMProxy *extractor,\n    vtkSMProxy *proxy)\n\nReturns true is the `extractor` is an extractor for the `proxy`.\n"},
  {"GetInputForExtractor", PyvtkSMExtractsController_GetInputForExtractor, METH_VARARGS,
   "V.GetInputForExtractor(vtkSMProxy) -> vtkSMProxy\nC++: vtkSMProxy *GetInputForExtractor(vtkSMProxy *extractor)\n\nGiven an extractor proxy, returns the producer for the extractor,\nif any. May return a vtkSMViewProxy or a vtkSMOutputPort.\n"},
  {"GetSummaryTable", PyvtkSMExtractsController_GetSummaryTable, METH_VARARGS,
   "V.GetSummaryTable() -> vtkTable\nC++: vtkTable *GetSummaryTable()\n\nGet access to the summary table generated so far. This will be\nnullptr until the first extract is generated.\n\nSee @ref GeneratingExtractsSummary for information about summary\ntable.\n"},
  {"ResetSummaryTable", PyvtkSMExtractsController_ResetSummaryTable, METH_VARARGS,
   "V.ResetSummaryTable()\nC++: void ResetSummaryTable()\n\nReset summary table.\n\nGenerally not needed since there is not much use for reusing\nvtkSMExtractsController, one should just create a new one when\nneeded.\n"},
  {"SaveSummaryTable", PyvtkSMExtractsController_SaveSummaryTable, METH_VARARGS,
   "V.SaveSummaryTable(string, vtkSMSessionProxyManager) -> bool\nC++: bool SaveSummaryTable(const std::string &fname,\n    vtkSMSessionProxyManager *pxm)\n\nSaves summary table to a file. Path is relative to the\nExtractsOutputDirectory.\n"},
  {"IsExtractorEnabled", PyvtkSMExtractsController_IsExtractorEnabled, METH_VARARGS,
   "V.IsExtractorEnabled(vtkSMProxy) -> bool\nC++: static bool IsExtractorEnabled(vtkSMProxy *extractor)\n\nReturns true of the extractor is enabled.\n"},
  {"SetExtractorEnabled", PyvtkSMExtractsController_SetExtractorEnabled, METH_VARARGS,
   "V.SetExtractorEnabled(vtkSMProxy, bool)\nC++: static void SetExtractorEnabled(vtkSMProxy *extractor,\n    bool val)\n\nEnable/disable an extractor.\n"},
  {nullptr, nullptr, 0, nullptr}
};

#ifdef VTK_PYTHON_NEEDS_DEPRECATION_WARNING_SUPPRESSION
#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
#endif

static PyTypeObject PyvtkSMExtractsController_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  PYTHON_PACKAGE_SCOPE "vtkRemotingServerManager.vtkSMExtractsController", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
#if PY_VERSION_HEX >= 0x03080000
  0, // tp_vectorcall_offset
#else
  nullptr, // tp_print
#endif
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkSMExtractsController_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkSMExtractsController_StaticNew()
{
  return vtkSMExtractsController::New();
}

PyObject *PyvtkSMExtractsController_ClassNew()
{
  PyTypeObject *pytype = PyVTKClass_Add(
    &PyvtkSMExtractsController_Type, PyvtkSMExtractsController_Methods,
    "vtkSMExtractsController",
 &PyvtkSMExtractsController_StaticNew);

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#ifndef VTK_PY3K
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = vtkPythonUtil::FindClassTypeObject("vtkObject");

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkSMExtractsController(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkSMExtractsController_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkSMExtractsController", o) != 0)
  {
    Py_DECREF(o);
  }

}

