/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkRemotingViewsObjectFactory.cxx

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/

// Object factories should never have deprecation warnings.
#define VTK_DEPRECATION_LEVEL 0

#include "vtkRemotingViewsObjectFactory.h"
#include "vtkVersion.h"

// Include all of the classes we want to create overrides for.
#include "vtkSMParaViewPipelineControllerWithRendering.h"


vtkStandardNewMacro(vtkRemotingViewsObjectFactory);

// Now create the functions to create overrides with.
VTK_CREATE_CREATE_FUNCTION(vtkSMParaViewPipelineControllerWithRendering)


vtkRemotingViewsObjectFactory::vtkRemotingViewsObjectFactory()
{
this->RegisterOverride("vtkSMParaViewPipelineController", "vtkSMParaViewPipelineControllerWithRendering", "Override for ParaView::RemotingViews module", 1, vtkObjectFactoryCreatevtkSMParaViewPipelineControllerWithRendering);

}

const char * vtkRemotingViewsObjectFactory::GetVTKSourceVersion()
{
  return VTK_SOURCE_VERSION;
}

void vtkRemotingViewsObjectFactory::PrintSelf(ostream &os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os, indent);
}

// Registration of object factories.
static unsigned int vtkRemotingViewsCount = 0;

VTKREMOTINGVIEWS_EXPORT void vtkRemotingViews_AutoInit_Construct()
{
  if(++vtkRemotingViewsCount == 1)
  {


    vtkRemotingViewsObjectFactory* factory = vtkRemotingViewsObjectFactory::New();
    if (factory)
    {
      // vtkObjectFactory keeps a reference to the "factory",
      vtkObjectFactory::RegisterFactory(factory);
      factory->Delete();
    }
  }
}
