/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkFiltersParallelGeometryObjectFactory.cxx

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/

// Object factories should never have deprecation warnings.
#define VTK_DEPRECATION_LEVEL 0

#include "vtkFiltersParallelGeometryObjectFactory.h"
#include "vtkVersion.h"

// Include all of the classes we want to create overrides for.
#include "vtkPConnectivityFilter.h"
#include "vtkPDistributedDataFilter.h"
#include "vtkPUnstructuredGridGhostCellsGenerator.h"


vtkStandardNewMacro(vtkFiltersParallelGeometryObjectFactory);

// Now create the functions to create overrides with.
VTK_CREATE_CREATE_FUNCTION(vtkPConnectivityFilter)
VTK_CREATE_CREATE_FUNCTION(vtkPDistributedDataFilter)
VTK_CREATE_CREATE_FUNCTION(vtkPUnstructuredGridGhostCellsGenerator)


vtkFiltersParallelGeometryObjectFactory::vtkFiltersParallelGeometryObjectFactory()
{
this->RegisterOverride("vtkConnectivityFilter", "vtkPConnectivityFilter", "Override for VTK::FiltersParallelGeometry module", 1, vtkObjectFactoryCreatevtkPConnectivityFilter);
this->RegisterOverride("vtkDistributedDataFilter", "vtkPDistributedDataFilter", "Override for VTK::FiltersParallelGeometry module", 1, vtkObjectFactoryCreatevtkPDistributedDataFilter);
this->RegisterOverride("vtkUnstructuredGridGhostCellsGenerator", "vtkPUnstructuredGridGhostCellsGenerator", "Override for VTK::FiltersParallelGeometry module", 1, vtkObjectFactoryCreatevtkPUnstructuredGridGhostCellsGenerator);

}

const char * vtkFiltersParallelGeometryObjectFactory::GetVTKSourceVersion()
{
  return VTK_SOURCE_VERSION;
}

void vtkFiltersParallelGeometryObjectFactory::PrintSelf(ostream &os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os, indent);
}

// Registration of object factories.
static unsigned int vtkFiltersParallelGeometryCount = 0;

VTKFILTERSPARALLELGEOMETRY_EXPORT void vtkFiltersParallelGeometry_AutoInit_Construct()
{
  if(++vtkFiltersParallelGeometryCount == 1)
  {


    vtkFiltersParallelGeometryObjectFactory* factory = vtkFiltersParallelGeometryObjectFactory::New();
    if (factory)
    {
      // vtkObjectFactory keeps a reference to the "factory",
      vtkObjectFactory::RegisterFactory(factory);
      factory->Delete();
    }
  }
}
