/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkIOMPIImageObjectFactory.cxx

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/

// Object factories should never have deprecation warnings.
#define VTK_DEPRECATION_LEVEL 0

#include "vtkIOMPIImageObjectFactory.h"
#include "vtkVersion.h"

// Include all of the classes we want to create overrides for.
#include "vtkPNrrdReader.h"
#include "vtkMPIImageReader.h"


vtkStandardNewMacro(vtkIOMPIImageObjectFactory);

// Now create the functions to create overrides with.
VTK_CREATE_CREATE_FUNCTION(vtkPNrrdReader)
VTK_CREATE_CREATE_FUNCTION(vtkMPIImageReader)


vtkIOMPIImageObjectFactory::vtkIOMPIImageObjectFactory()
{
this->RegisterOverride("vtkNrrdReader", "vtkPNrrdReader", "Override for VTK::IOMPIImage module", 1, vtkObjectFactoryCreatevtkPNrrdReader);
this->RegisterOverride("vtkImageReader", "vtkMPIImageReader", "Override for VTK::IOMPIImage module", 1, vtkObjectFactoryCreatevtkMPIImageReader);

}

const char * vtkIOMPIImageObjectFactory::GetVTKSourceVersion()
{
  return VTK_SOURCE_VERSION;
}

void vtkIOMPIImageObjectFactory::PrintSelf(ostream &os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os, indent);
}

// Registration of object factories.
static unsigned int vtkIOMPIImageCount = 0;

VTKIOMPIIMAGE_EXPORT void vtkIOMPIImage_AutoInit_Construct()
{
  if(++vtkIOMPIImageCount == 1)
  {


    vtkIOMPIImageObjectFactory* factory = vtkIOMPIImageObjectFactory::New();
    if (factory)
    {
      // vtkObjectFactory keeps a reference to the "factory",
      vtkObjectFactory::RegisterFactory(factory);
      factory->Delete();
    }
  }
}
